/**
 * Copyright (c) 2014,2019 Contributors to the Eclipse Foundation
 *
 * See the NOTICE file(s) distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License 2.0 which is available at
 * http://www.eclipse.org/legal/epl-2.0
 *
 * SPDX-License-Identifier: EPL-2.0
 */
package org.eclipse.smarthome.binding.tinkerforge.internal;

import java.net.URI;
import java.net.URISyntaxException;
import java.util.Arrays;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.eclipse.jdt.annotation.NonNullByDefault;
import org.eclipse.smarthome.core.thing.ThingTypeUID;
import org.eclipse.smarthome.core.thing.type.ChannelTypeUID;

/**
 * The {@link TinkerforgeBindingConstants} class defines common constants, which are
 * used across the whole binding.
 *
 * @author Erik Fleckstein - Initial contribution
 */
@NonNullByDefault
public class TinkerforgeBindingConstants {

    public static final String BINDING_ID = "tinkerforge";

    // List of all Thing Type UIDs
    public static final ThingTypeUID THING_TYPE_BRICK_DAEMON = new ThingTypeUID(BINDING_ID, "brickd");
    public static final ThingTypeUID THING_TYPE_DC = new ThingTypeUID(BINDING_ID, "dc");
	public static final ThingTypeUID THING_TYPE_HAT = new ThingTypeUID(BINDING_ID, "hat");
	public static final ThingTypeUID THING_TYPE_HAT_ZERO = new ThingTypeUID(BINDING_ID, "hatzero");
	public static final ThingTypeUID THING_TYPE_IMU = new ThingTypeUID(BINDING_ID, "imu");
	public static final ThingTypeUID THING_TYPE_IMU_V2 = new ThingTypeUID(BINDING_ID, "imuv2");
	public static final ThingTypeUID THING_TYPE_MASTER = new ThingTypeUID(BINDING_ID, "master");
	public static final ThingTypeUID THING_TYPE_RED = new ThingTypeUID(BINDING_ID, "red");
	public static final ThingTypeUID THING_TYPE_SERVO = new ThingTypeUID(BINDING_ID, "servo");
	public static final ThingTypeUID THING_TYPE_SILENT_STEPPER = new ThingTypeUID(BINDING_ID, "silentstepper");
	public static final ThingTypeUID THING_TYPE_STEPPER = new ThingTypeUID(BINDING_ID, "stepper");
	public static final ThingTypeUID THING_TYPE_ACCELEROMETER = new ThingTypeUID(BINDING_ID, "accelerometer");
	public static final ThingTypeUID THING_TYPE_ACCELEROMETER_V2 = new ThingTypeUID(BINDING_ID, "accelerometerv2");
	public static final ThingTypeUID THING_TYPE_AIR_QUALITY = new ThingTypeUID(BINDING_ID, "airquality");
	public static final ThingTypeUID THING_TYPE_AMBIENT_LIGHT = new ThingTypeUID(BINDING_ID, "ambientlight");
	public static final ThingTypeUID THING_TYPE_AMBIENT_LIGHT_V2 = new ThingTypeUID(BINDING_ID, "ambientlightv2");
	public static final ThingTypeUID THING_TYPE_AMBIENT_LIGHT_V3 = new ThingTypeUID(BINDING_ID, "ambientlightv3");
	public static final ThingTypeUID THING_TYPE_ANALOG_IN = new ThingTypeUID(BINDING_ID, "analogin");
	public static final ThingTypeUID THING_TYPE_ANALOG_IN_V2 = new ThingTypeUID(BINDING_ID, "analoginv2");
	public static final ThingTypeUID THING_TYPE_ANALOG_IN_V3 = new ThingTypeUID(BINDING_ID, "analoginv3");
	public static final ThingTypeUID THING_TYPE_ANALOG_OUT = new ThingTypeUID(BINDING_ID, "analogout");
	public static final ThingTypeUID THING_TYPE_ANALOG_OUT_V2 = new ThingTypeUID(BINDING_ID, "analogoutv2");
	public static final ThingTypeUID THING_TYPE_ANALOG_OUT_V3 = new ThingTypeUID(BINDING_ID, "analogoutv3");
	public static final ThingTypeUID THING_TYPE_BAROMETER = new ThingTypeUID(BINDING_ID, "barometer");
	public static final ThingTypeUID THING_TYPE_BAROMETER_V2 = new ThingTypeUID(BINDING_ID, "barometerv2");
	public static final ThingTypeUID THING_TYPE_CAN = new ThingTypeUID(BINDING_ID, "can");
	public static final ThingTypeUID THING_TYPE_CAN_V2 = new ThingTypeUID(BINDING_ID, "canv2");
	public static final ThingTypeUID THING_TYPE_CO2 = new ThingTypeUID(BINDING_ID, "co2");
	public static final ThingTypeUID THING_TYPE_CO2_V2 = new ThingTypeUID(BINDING_ID, "co2v2");
	public static final ThingTypeUID THING_TYPE_COLOR = new ThingTypeUID(BINDING_ID, "color");
	public static final ThingTypeUID THING_TYPE_COLOR_V2 = new ThingTypeUID(BINDING_ID, "colorv2");
	public static final ThingTypeUID THING_TYPE_COMPASS = new ThingTypeUID(BINDING_ID, "compass");
	public static final ThingTypeUID THING_TYPE_CURRENT12 = new ThingTypeUID(BINDING_ID, "current12");
	public static final ThingTypeUID THING_TYPE_CURRENT25 = new ThingTypeUID(BINDING_ID, "current25");
	public static final ThingTypeUID THING_TYPE_DISTANCE_IR = new ThingTypeUID(BINDING_ID, "distanceir");
	public static final ThingTypeUID THING_TYPE_DISTANCE_IR_V2 = new ThingTypeUID(BINDING_ID, "distanceirv2");
	public static final ThingTypeUID THING_TYPE_DISTANCE_US = new ThingTypeUID(BINDING_ID, "distanceus");
	public static final ThingTypeUID THING_TYPE_DISTANCE_US_V2 = new ThingTypeUID(BINDING_ID, "distanceusv2");
	public static final ThingTypeUID THING_TYPE_DMX = new ThingTypeUID(BINDING_ID, "dmx");
	public static final ThingTypeUID THING_TYPE_DUAL_BUTTON = new ThingTypeUID(BINDING_ID, "dualbutton");
	public static final ThingTypeUID THING_TYPE_DUAL_BUTTON_V2 = new ThingTypeUID(BINDING_ID, "dualbuttonv2");
	public static final ThingTypeUID THING_TYPE_DUAL_RELAY = new ThingTypeUID(BINDING_ID, "dualrelay");
	public static final ThingTypeUID THING_TYPE_DUST_DETECTOR = new ThingTypeUID(BINDING_ID, "dustdetector");
	public static final ThingTypeUID THING_TYPE_E_PAPER_296X128 = new ThingTypeUID(BINDING_ID, "epaper296x128");
	public static final ThingTypeUID THING_TYPE_ENERGY_MONITOR = new ThingTypeUID(BINDING_ID, "energymonitor");
	public static final ThingTypeUID THING_TYPE_GPS = new ThingTypeUID(BINDING_ID, "gps");
	public static final ThingTypeUID THING_TYPE_GPS_V2 = new ThingTypeUID(BINDING_ID, "gpsv2");
	public static final ThingTypeUID THING_TYPE_HALL_EFFECT = new ThingTypeUID(BINDING_ID, "halleffect");
	public static final ThingTypeUID THING_TYPE_HALL_EFFECT_V2 = new ThingTypeUID(BINDING_ID, "halleffectv2");
	public static final ThingTypeUID THING_TYPE_HUMIDITY = new ThingTypeUID(BINDING_ID, "humidity");
	public static final ThingTypeUID THING_TYPE_HUMIDITY_V2 = new ThingTypeUID(BINDING_ID, "humidityv2");
	public static final ThingTypeUID THING_TYPE_INDUSTRIAL_ANALOG_OUT = new ThingTypeUID(BINDING_ID, "industrialanalogout");
	public static final ThingTypeUID THING_TYPE_INDUSTRIAL_ANALOG_OUT_V2 = new ThingTypeUID(BINDING_ID, "industrialanalogoutv2");
	public static final ThingTypeUID THING_TYPE_INDUSTRIAL_COUNTER = new ThingTypeUID(BINDING_ID, "industrialcounter");
	public static final ThingTypeUID THING_TYPE_INDUSTRIAL_DIGITAL_IN_4 = new ThingTypeUID(BINDING_ID, "industrialdigitalin4");
	public static final ThingTypeUID THING_TYPE_INDUSTRIAL_DIGITAL_IN_4_V2 = new ThingTypeUID(BINDING_ID, "industrialdigitalin4v2");
	public static final ThingTypeUID THING_TYPE_INDUSTRIAL_DIGITAL_OUT_4 = new ThingTypeUID(BINDING_ID, "industrialdigitalout4");
	public static final ThingTypeUID THING_TYPE_INDUSTRIAL_DIGITAL_OUT_4_V2 = new ThingTypeUID(BINDING_ID, "industrialdigitalout4v2");
	public static final ThingTypeUID THING_TYPE_INDUSTRIAL_DUAL_0_20MA = new ThingTypeUID(BINDING_ID, "industrialdual020ma");
	public static final ThingTypeUID THING_TYPE_INDUSTRIAL_DUAL_0_20MA_V2 = new ThingTypeUID(BINDING_ID, "industrialdual020mav2");
	public static final ThingTypeUID THING_TYPE_INDUSTRIAL_DUAL_ANALOG_IN = new ThingTypeUID(BINDING_ID, "industrialdualanalogin");
	public static final ThingTypeUID THING_TYPE_INDUSTRIAL_DUAL_ANALOG_IN_V2 = new ThingTypeUID(BINDING_ID, "industrialdualanaloginv2");
	public static final ThingTypeUID THING_TYPE_INDUSTRIAL_DUAL_RELAY = new ThingTypeUID(BINDING_ID, "industrialdualrelay");
	public static final ThingTypeUID THING_TYPE_INDUSTRIAL_QUAD_RELAY = new ThingTypeUID(BINDING_ID, "industrialquadrelay");
	public static final ThingTypeUID THING_TYPE_INDUSTRIAL_QUAD_RELAY_V2 = new ThingTypeUID(BINDING_ID, "industrialquadrelayv2");
	public static final ThingTypeUID THING_TYPE_IO16 = new ThingTypeUID(BINDING_ID, "io16");
	public static final ThingTypeUID THING_TYPE_IO16_V2 = new ThingTypeUID(BINDING_ID, "io16v2");
	public static final ThingTypeUID THING_TYPE_IO4 = new ThingTypeUID(BINDING_ID, "io4");
	public static final ThingTypeUID THING_TYPE_IO4_V2 = new ThingTypeUID(BINDING_ID, "io4v2");
	public static final ThingTypeUID THING_TYPE_ISOLATOR = new ThingTypeUID(BINDING_ID, "isolator");
	public static final ThingTypeUID THING_TYPE_JOYSTICK = new ThingTypeUID(BINDING_ID, "joystick");
	public static final ThingTypeUID THING_TYPE_JOYSTICK_V2 = new ThingTypeUID(BINDING_ID, "joystickv2");
	public static final ThingTypeUID THING_TYPE_LASER_RANGE_FINDER = new ThingTypeUID(BINDING_ID, "laserrangefinder");
	public static final ThingTypeUID THING_TYPE_LASER_RANGE_FINDER_V2 = new ThingTypeUID(BINDING_ID, "laserrangefinderv2");
	public static final ThingTypeUID THING_TYPE_LCD_128X64 = new ThingTypeUID(BINDING_ID, "lcd128x64");
	public static final ThingTypeUID THING_TYPE_LCD_16X2 = new ThingTypeUID(BINDING_ID, "lcd16x2");
	public static final ThingTypeUID THING_TYPE_LCD_20X4 = new ThingTypeUID(BINDING_ID, "lcd20x4");
	public static final ThingTypeUID THING_TYPE_LED_STRIP = new ThingTypeUID(BINDING_ID, "ledstrip");
	public static final ThingTypeUID THING_TYPE_LED_STRIP_V2 = new ThingTypeUID(BINDING_ID, "ledstripv2");
	public static final ThingTypeUID THING_TYPE_LINE = new ThingTypeUID(BINDING_ID, "line");
	public static final ThingTypeUID THING_TYPE_LINEAR_POTI = new ThingTypeUID(BINDING_ID, "linearpoti");
	public static final ThingTypeUID THING_TYPE_LINEAR_POTI_V2 = new ThingTypeUID(BINDING_ID, "linearpotiv2");
	public static final ThingTypeUID THING_TYPE_LOAD_CELL = new ThingTypeUID(BINDING_ID, "loadcell");
	public static final ThingTypeUID THING_TYPE_LOAD_CELL_V2 = new ThingTypeUID(BINDING_ID, "loadcellv2");
	public static final ThingTypeUID THING_TYPE_MOISTURE = new ThingTypeUID(BINDING_ID, "moisture");
	public static final ThingTypeUID THING_TYPE_MOTION_DETECTOR = new ThingTypeUID(BINDING_ID, "motiondetector");
	public static final ThingTypeUID THING_TYPE_MOTION_DETECTOR_V2 = new ThingTypeUID(BINDING_ID, "motiondetectorv2");
	public static final ThingTypeUID THING_TYPE_MOTORIZED_LINEAR_POTI = new ThingTypeUID(BINDING_ID, "motorizedlinearpoti");
	public static final ThingTypeUID THING_TYPE_MULTI_TOUCH = new ThingTypeUID(BINDING_ID, "multitouch");
	public static final ThingTypeUID THING_TYPE_MULTI_TOUCH_V2 = new ThingTypeUID(BINDING_ID, "multitouchv2");
	public static final ThingTypeUID THING_TYPE_NFC = new ThingTypeUID(BINDING_ID, "nfc");
	public static final ThingTypeUID THING_TYPE_NFC_RFID = new ThingTypeUID(BINDING_ID, "nfcrfid");
	public static final ThingTypeUID THING_TYPE_OLED_128X64 = new ThingTypeUID(BINDING_ID, "oled128x64");
	public static final ThingTypeUID THING_TYPE_OLED_128X64_V2 = new ThingTypeUID(BINDING_ID, "oled128x64v2");
	public static final ThingTypeUID THING_TYPE_OLED_64X48 = new ThingTypeUID(BINDING_ID, "oled64x48");
	public static final ThingTypeUID THING_TYPE_ONE_WIRE = new ThingTypeUID(BINDING_ID, "onewire");
	public static final ThingTypeUID THING_TYPE_OUTDOOR_WEATHER = new ThingTypeUID(BINDING_ID, "outdoorweather");
	public static final ThingTypeUID THING_TYPE_PARTICULATE_MATTER = new ThingTypeUID(BINDING_ID, "particulatematter");
	public static final ThingTypeUID THING_TYPE_PIEZO_BUZZER = new ThingTypeUID(BINDING_ID, "piezobuzzer");
	public static final ThingTypeUID THING_TYPE_PIEZO_SPEAKER = new ThingTypeUID(BINDING_ID, "piezospeaker");
	public static final ThingTypeUID THING_TYPE_PIEZO_SPEAKER_V2 = new ThingTypeUID(BINDING_ID, "piezospeakerv2");
	public static final ThingTypeUID THING_TYPE_PTC = new ThingTypeUID(BINDING_ID, "ptc");
	public static final ThingTypeUID THING_TYPE_PTC_V2 = new ThingTypeUID(BINDING_ID, "ptcv2");
	public static final ThingTypeUID THING_TYPE_REAL_TIME_CLOCK = new ThingTypeUID(BINDING_ID, "realtimeclock");
	public static final ThingTypeUID THING_TYPE_REAL_TIME_CLOCK_V2 = new ThingTypeUID(BINDING_ID, "realtimeclockv2");
	public static final ThingTypeUID THING_TYPE_REMOTE_SWITCH = new ThingTypeUID(BINDING_ID, "remoteswitch");
	public static final ThingTypeUID THING_TYPE_REMOTE_SWITCH_V2 = new ThingTypeUID(BINDING_ID, "remoteswitchv2");
	public static final ThingTypeUID THING_TYPE_RGB_LED_BUTTON = new ThingTypeUID(BINDING_ID, "rgbledbutton");
	public static final ThingTypeUID THING_TYPE_RGB_LED = new ThingTypeUID(BINDING_ID, "rgbled");
	public static final ThingTypeUID THING_TYPE_RGB_LED_MATRIX = new ThingTypeUID(BINDING_ID, "rgbledmatrix");
	public static final ThingTypeUID THING_TYPE_RGB_LED_V2 = new ThingTypeUID(BINDING_ID, "rgbledv2");
	public static final ThingTypeUID THING_TYPE_ROTARY_ENCODER = new ThingTypeUID(BINDING_ID, "rotaryencoder");
	public static final ThingTypeUID THING_TYPE_ROTARY_ENCODER_V2 = new ThingTypeUID(BINDING_ID, "rotaryencoderv2");
	public static final ThingTypeUID THING_TYPE_ROTARY_POTI = new ThingTypeUID(BINDING_ID, "rotarypoti");
	public static final ThingTypeUID THING_TYPE_ROTARY_POTI_V2 = new ThingTypeUID(BINDING_ID, "rotarypotiv2");
	public static final ThingTypeUID THING_TYPE_RS232 = new ThingTypeUID(BINDING_ID, "rs232");
	public static final ThingTypeUID THING_TYPE_RS232_V2 = new ThingTypeUID(BINDING_ID, "rs232v2");
	public static final ThingTypeUID THING_TYPE_RS485 = new ThingTypeUID(BINDING_ID, "rs485");
	public static final ThingTypeUID THING_TYPE_SEGMENT_DISPLAY_4X7 = new ThingTypeUID(BINDING_ID, "segmentdisplay4x7");
	public static final ThingTypeUID THING_TYPE_SEGMENT_DISPLAY_4X7_V2 = new ThingTypeUID(BINDING_ID, "segmentdisplay4x7v2");
	public static final ThingTypeUID THING_TYPE_SOLID_STATE_RELAY = new ThingTypeUID(BINDING_ID, "solidstaterelay");
	public static final ThingTypeUID THING_TYPE_SOLID_STATE_RELAY_V2 = new ThingTypeUID(BINDING_ID, "solidstaterelayv2");
	public static final ThingTypeUID THING_TYPE_SOUND_INTENSITY = new ThingTypeUID(BINDING_ID, "soundintensity");
	public static final ThingTypeUID THING_TYPE_SOUND_PRESSURE_LEVEL = new ThingTypeUID(BINDING_ID, "soundpressurelevel");
	public static final ThingTypeUID THING_TYPE_TEMPERATURE = new ThingTypeUID(BINDING_ID, "temperature");
	public static final ThingTypeUID THING_TYPE_TEMPERATURE_IR = new ThingTypeUID(BINDING_ID, "temperatureir");
	public static final ThingTypeUID THING_TYPE_TEMPERATURE_IR_V2 = new ThingTypeUID(BINDING_ID, "temperatureirv2");
	public static final ThingTypeUID THING_TYPE_TEMPERATURE_V2 = new ThingTypeUID(BINDING_ID, "temperaturev2");
	public static final ThingTypeUID THING_TYPE_THERMAL_IMAGING = new ThingTypeUID(BINDING_ID, "thermalimaging");
	public static final ThingTypeUID THING_TYPE_THERMOCOUPLE = new ThingTypeUID(BINDING_ID, "thermocouple");
	public static final ThingTypeUID THING_TYPE_THERMOCOUPLE_V2 = new ThingTypeUID(BINDING_ID, "thermocouplev2");
	public static final ThingTypeUID THING_TYPE_TILT = new ThingTypeUID(BINDING_ID, "tilt");
	public static final ThingTypeUID THING_TYPE_UV_LIGHT = new ThingTypeUID(BINDING_ID, "uvlight");
	public static final ThingTypeUID THING_TYPE_UV_LIGHT_V2 = new ThingTypeUID(BINDING_ID, "uvlightv2");
	public static final ThingTypeUID THING_TYPE_VOLTAGE = new ThingTypeUID(BINDING_ID, "voltage");
	public static final ThingTypeUID THING_TYPE_VOLTAGE_CURRENT = new ThingTypeUID(BINDING_ID, "voltagecurrent");
	public static final ThingTypeUID THING_TYPE_VOLTAGE_CURRENT_V2 = new ThingTypeUID(BINDING_ID, "voltagecurrentv2");
	public static final ThingTypeUID THING_TYPE_XMC1400_BREAKOUT = new ThingTypeUID(BINDING_ID, "xmc1400breakout");

    public static final List<ThingTypeUID> SUPPORTED_DEVICES = Arrays.asList(THING_TYPE_BRICK_DAEMON,
        THING_TYPE_DC,
		THING_TYPE_HAT,
		THING_TYPE_HAT_ZERO,
		THING_TYPE_IMU,
		THING_TYPE_IMU_V2,
		THING_TYPE_MASTER,
		THING_TYPE_RED,
		THING_TYPE_SERVO,
		THING_TYPE_SILENT_STEPPER,
		THING_TYPE_STEPPER,
		THING_TYPE_ACCELEROMETER,
		THING_TYPE_ACCELEROMETER_V2,
		THING_TYPE_AIR_QUALITY,
		THING_TYPE_AMBIENT_LIGHT,
		THING_TYPE_AMBIENT_LIGHT_V2,
		THING_TYPE_AMBIENT_LIGHT_V3,
		THING_TYPE_ANALOG_IN,
		THING_TYPE_ANALOG_IN_V2,
		THING_TYPE_ANALOG_IN_V3,
		THING_TYPE_ANALOG_OUT,
		THING_TYPE_ANALOG_OUT_V2,
		THING_TYPE_ANALOG_OUT_V3,
		THING_TYPE_BAROMETER,
		THING_TYPE_BAROMETER_V2,
		THING_TYPE_CAN,
		THING_TYPE_CAN_V2,
		THING_TYPE_CO2,
		THING_TYPE_CO2_V2,
		THING_TYPE_COLOR,
		THING_TYPE_COLOR_V2,
		THING_TYPE_COMPASS,
		THING_TYPE_CURRENT12,
		THING_TYPE_CURRENT25,
		THING_TYPE_DISTANCE_IR,
		THING_TYPE_DISTANCE_IR_V2,
		THING_TYPE_DISTANCE_US,
		THING_TYPE_DISTANCE_US_V2,
		THING_TYPE_DMX,
		THING_TYPE_DUAL_BUTTON,
		THING_TYPE_DUAL_BUTTON_V2,
		THING_TYPE_DUAL_RELAY,
		THING_TYPE_DUST_DETECTOR,
		THING_TYPE_E_PAPER_296X128,
		THING_TYPE_ENERGY_MONITOR,
		THING_TYPE_GPS,
		THING_TYPE_GPS_V2,
		THING_TYPE_HALL_EFFECT,
		THING_TYPE_HALL_EFFECT_V2,
		THING_TYPE_HUMIDITY,
		THING_TYPE_HUMIDITY_V2,
		THING_TYPE_INDUSTRIAL_ANALOG_OUT,
		THING_TYPE_INDUSTRIAL_ANALOG_OUT_V2,
		THING_TYPE_INDUSTRIAL_COUNTER,
		THING_TYPE_INDUSTRIAL_DIGITAL_IN_4,
		THING_TYPE_INDUSTRIAL_DIGITAL_IN_4_V2,
		THING_TYPE_INDUSTRIAL_DIGITAL_OUT_4,
		THING_TYPE_INDUSTRIAL_DIGITAL_OUT_4_V2,
		THING_TYPE_INDUSTRIAL_DUAL_0_20MA,
		THING_TYPE_INDUSTRIAL_DUAL_0_20MA_V2,
		THING_TYPE_INDUSTRIAL_DUAL_ANALOG_IN,
		THING_TYPE_INDUSTRIAL_DUAL_ANALOG_IN_V2,
		THING_TYPE_INDUSTRIAL_DUAL_RELAY,
		THING_TYPE_INDUSTRIAL_QUAD_RELAY,
		THING_TYPE_INDUSTRIAL_QUAD_RELAY_V2,
		THING_TYPE_IO16,
		THING_TYPE_IO16_V2,
		THING_TYPE_IO4,
		THING_TYPE_IO4_V2,
		THING_TYPE_ISOLATOR,
		THING_TYPE_JOYSTICK,
		THING_TYPE_JOYSTICK_V2,
		THING_TYPE_LASER_RANGE_FINDER,
		THING_TYPE_LASER_RANGE_FINDER_V2,
		THING_TYPE_LCD_128X64,
		THING_TYPE_LCD_16X2,
		THING_TYPE_LCD_20X4,
		THING_TYPE_LED_STRIP,
		THING_TYPE_LED_STRIP_V2,
		THING_TYPE_LINE,
		THING_TYPE_LINEAR_POTI,
		THING_TYPE_LINEAR_POTI_V2,
		THING_TYPE_LOAD_CELL,
		THING_TYPE_LOAD_CELL_V2,
		THING_TYPE_MOISTURE,
		THING_TYPE_MOTION_DETECTOR,
		THING_TYPE_MOTION_DETECTOR_V2,
		THING_TYPE_MOTORIZED_LINEAR_POTI,
		THING_TYPE_MULTI_TOUCH,
		THING_TYPE_MULTI_TOUCH_V2,
		THING_TYPE_NFC,
		THING_TYPE_NFC_RFID,
		THING_TYPE_OLED_128X64,
		THING_TYPE_OLED_128X64_V2,
		THING_TYPE_OLED_64X48,
		THING_TYPE_ONE_WIRE,
		THING_TYPE_OUTDOOR_WEATHER,
		THING_TYPE_PARTICULATE_MATTER,
		THING_TYPE_PIEZO_BUZZER,
		THING_TYPE_PIEZO_SPEAKER,
		THING_TYPE_PIEZO_SPEAKER_V2,
		THING_TYPE_PTC,
		THING_TYPE_PTC_V2,
		THING_TYPE_REAL_TIME_CLOCK,
		THING_TYPE_REAL_TIME_CLOCK_V2,
		THING_TYPE_REMOTE_SWITCH,
		THING_TYPE_REMOTE_SWITCH_V2,
		THING_TYPE_RGB_LED_BUTTON,
		THING_TYPE_RGB_LED,
		THING_TYPE_RGB_LED_MATRIX,
		THING_TYPE_RGB_LED_V2,
		THING_TYPE_ROTARY_ENCODER,
		THING_TYPE_ROTARY_ENCODER_V2,
		THING_TYPE_ROTARY_POTI,
		THING_TYPE_ROTARY_POTI_V2,
		THING_TYPE_RS232,
		THING_TYPE_RS232_V2,
		THING_TYPE_RS485,
		THING_TYPE_SEGMENT_DISPLAY_4X7,
		THING_TYPE_SEGMENT_DISPLAY_4X7_V2,
		THING_TYPE_SOLID_STATE_RELAY,
		THING_TYPE_SOLID_STATE_RELAY_V2,
		THING_TYPE_SOUND_INTENSITY,
		THING_TYPE_SOUND_PRESSURE_LEVEL,
		THING_TYPE_TEMPERATURE,
		THING_TYPE_TEMPERATURE_IR,
		THING_TYPE_TEMPERATURE_IR_V2,
		THING_TYPE_TEMPERATURE_V2,
		THING_TYPE_THERMAL_IMAGING,
		THING_TYPE_THERMOCOUPLE,
		THING_TYPE_THERMOCOUPLE_V2,
		THING_TYPE_TILT,
		THING_TYPE_UV_LIGHT,
		THING_TYPE_UV_LIGHT_V2,
		THING_TYPE_VOLTAGE,
		THING_TYPE_VOLTAGE_CURRENT,
		THING_TYPE_VOLTAGE_CURRENT_V2,
		THING_TYPE_XMC1400_BREAKOUT);

    // List of all Channel Type UIDs
    public static final ChannelTypeUID CHANNEL_TYPE_AIR_QUALITY_HUMIDITY = new ChannelTypeUID(BINDING_ID, "AirQualityHumidity");
	public static final ChannelTypeUID CHANNEL_TYPE_AIR_QUALITY_TEMPERATURE = new ChannelTypeUID(BINDING_ID, "AirQualityTemperature");
	public static final ChannelTypeUID CHANNEL_TYPE_AIR_QUALITY_AIR_PRESSURE = new ChannelTypeUID(BINDING_ID, "AirQualityAirPressure");
	public static final ChannelTypeUID CHANNEL_TYPE_AIR_QUALITY_IAQ_INDEX = new ChannelTypeUID(BINDING_ID, "AirQualityIAQIndex");
	public static final ChannelTypeUID CHANNEL_TYPE_AIR_QUALITY_IAQ_INDEX_ACCURACY = new ChannelTypeUID(BINDING_ID, "AirQualityIAQIndexAccuracy");
	public static final ChannelTypeUID CHANNEL_TYPE_AMBIENT_LIGHT_ILLUMINANCE = new ChannelTypeUID(BINDING_ID, "AmbientLightIlluminance");
	public static final ChannelTypeUID CHANNEL_TYPE_AMBIENT_LIGHT_V2_ILLUMINANCE = new ChannelTypeUID(BINDING_ID, "AmbientLightV2Illuminance");
	public static final ChannelTypeUID CHANNEL_TYPE_AMBIENT_LIGHT_V3_ILLUMINANCE = new ChannelTypeUID(BINDING_ID, "AmbientLightV3Illuminance");
	public static final ChannelTypeUID CHANNEL_TYPE_ANALOG_IN_V3_VOLTAGE = new ChannelTypeUID(BINDING_ID, "AnalogInV3Voltage");
	public static final ChannelTypeUID CHANNEL_TYPE_BAROMETER_AIR_PRESSURE = new ChannelTypeUID(BINDING_ID, "BarometerAirPressure");
	public static final ChannelTypeUID CHANNEL_TYPE_BAROMETER_ALTITUDE = new ChannelTypeUID(BINDING_ID, "BarometerAltitude");
	public static final ChannelTypeUID CHANNEL_TYPE_BAROMETER_V2_AIR_PRESSURE = new ChannelTypeUID(BINDING_ID, "BarometerV2AirPressure");
	public static final ChannelTypeUID CHANNEL_TYPE_BAROMETER_V2_ALTITUDE = new ChannelTypeUID(BINDING_ID, "BarometerV2Altitude");
	public static final ChannelTypeUID CHANNEL_TYPE_BAROMETER_V2_TEMPERATURE = new ChannelTypeUID(BINDING_ID, "BarometerV2Temperature");
	public static final ChannelTypeUID CHANNEL_TYPE_COLOR_COLOR = new ChannelTypeUID(BINDING_ID, "ColorColor");
	public static final ChannelTypeUID CHANNEL_TYPE_COLOR_V2_COLOR = new ChannelTypeUID(BINDING_ID, "ColorV2Color");
	public static final ChannelTypeUID CHANNEL_TYPE_COLOR_V2_ILLUMINANCE = new ChannelTypeUID(BINDING_ID, "ColorV2Illuminance");
	public static final ChannelTypeUID CHANNEL_TYPE_COLOR_V2_COLOR_TEMPERATURE = new ChannelTypeUID(BINDING_ID, "ColorV2ColorTemperature");
	public static final ChannelTypeUID CHANNEL_TYPE_COLOR_V2_LIGHT = new ChannelTypeUID(BINDING_ID, "ColorV2Light");
	public static final ChannelTypeUID CHANNEL_TYPE_COMPASS_HEADING = new ChannelTypeUID(BINDING_ID, "CompassHeading");
	public static final ChannelTypeUID CHANNEL_TYPE_DISTANCE_IR_DISTANCE = new ChannelTypeUID(BINDING_ID, "DistanceIRDistance");
	public static final ChannelTypeUID CHANNEL_TYPE_DISTANCE_IR_V2_DISTANCE = new ChannelTypeUID(BINDING_ID, "DistanceIRV2Distance");
	public static final ChannelTypeUID CHANNEL_TYPE_DISTANCE_US_DISTANCE = new ChannelTypeUID(BINDING_ID, "DistanceUSDistance");
	public static final ChannelTypeUID CHANNEL_TYPE_DISTANCE_US_V2_DISTANCE = new ChannelTypeUID(BINDING_ID, "DistanceUSV2Distance");
	public static final ChannelTypeUID CHANNEL_TYPE_DUAL_RELAY_RELAY = new ChannelTypeUID(BINDING_ID, "DualRelayRelay");
	public static final ChannelTypeUID CHANNEL_TYPE_DUAL_RELAY_MONOFLOP = new ChannelTypeUID(BINDING_ID, "DualRelayMonoflop");
	public static final ChannelTypeUID CHANNEL_TYPE_ENERGY_MONITOR_VOLTAGE = new ChannelTypeUID(BINDING_ID, "EnergyMonitorVoltage");
	public static final ChannelTypeUID CHANNEL_TYPE_ENERGY_MONITOR_CURRENT = new ChannelTypeUID(BINDING_ID, "EnergyMonitorCurrent");
	public static final ChannelTypeUID CHANNEL_TYPE_ENERGY_MONITOR_ENERGY = new ChannelTypeUID(BINDING_ID, "EnergyMonitorEnergy");
	public static final ChannelTypeUID CHANNEL_TYPE_ENERGY_MONITOR_REALPOWER = new ChannelTypeUID(BINDING_ID, "EnergyMonitorRealPower");
	public static final ChannelTypeUID CHANNEL_TYPE_ENERGY_MONITOR_APPPOWER = new ChannelTypeUID(BINDING_ID, "EnergyMonitorAppPower");
	public static final ChannelTypeUID CHANNEL_TYPE_ENERGY_MONITOR_REACPOWER = new ChannelTypeUID(BINDING_ID, "EnergyMonitorReacPower");
	public static final ChannelTypeUID CHANNEL_TYPE_ENERGY_MONITOR_FACTOR = new ChannelTypeUID(BINDING_ID, "EnergyMonitorFactor");
	public static final ChannelTypeUID CHANNEL_TYPE_ENERGY_MONITOR_FREQUENCY = new ChannelTypeUID(BINDING_ID, "EnergyMonitorFrequency");
	public static final ChannelTypeUID CHANNEL_TYPE_ENERGY_MONITOR_RESET = new ChannelTypeUID(BINDING_ID, "EnergyMonitorReset");
	public static final ChannelTypeUID CHANNEL_TYPE_HUMIDITY_HUMIDITY = new ChannelTypeUID(BINDING_ID, "HumidityHumidity");
	public static final ChannelTypeUID CHANNEL_TYPE_HUMIDITY_V2_HUMIDITY = new ChannelTypeUID(BINDING_ID, "HumidityV2Humidity");
	public static final ChannelTypeUID CHANNEL_TYPE_HUMIDITY_V2_TEMPERATURE = new ChannelTypeUID(BINDING_ID, "HumidityV2Temperature");
	public static final ChannelTypeUID CHANNEL_TYPE_INDUSTRIAL_ANALOG_OUT_V2_ENABLED = new ChannelTypeUID(BINDING_ID, "IndustrialAnalogOutV2Enabled");
	public static final ChannelTypeUID CHANNEL_TYPE_INDUSTRIAL_ANALOG_OUT_V2_VOLTAGE = new ChannelTypeUID(BINDING_ID, "IndustrialAnalogOutV2Voltage");
	public static final ChannelTypeUID CHANNEL_TYPE_INDUSTRIAL_ANALOG_OUT_V2_CURRENT = new ChannelTypeUID(BINDING_ID, "IndustrialAnalogOutV2Current");
	public static final ChannelTypeUID CHANNEL_TYPE_INDUSTRIAL_DIGITAL_IN_4_V2_INPUT = new ChannelTypeUID(BINDING_ID, "IndustrialDigitalIn4V2Input");
	public static final ChannelTypeUID CHANNEL_TYPE_INDUSTRIAL_DIGITAL_IN_4_V2_EDGE_COUNT = new ChannelTypeUID(BINDING_ID, "IndustrialDigitalIn4V2EdgeCount");
	public static final ChannelTypeUID CHANNEL_TYPE_INDUSTRIAL_DUAL_ANALOG_IN_VOLTAGE = new ChannelTypeUID(BINDING_ID, "IndustrialDualAnalogInVoltage");
	public static final ChannelTypeUID CHANNEL_TYPE_INDUSTRIAL_DUAL_ANALOG_IN_V2_VOLTAGE = new ChannelTypeUID(BINDING_ID, "IndustrialDualAnalogInV2Voltage");
	public static final ChannelTypeUID CHANNEL_TYPE_INDUSTRIAL_DUAL_RELAY_RELAY = new ChannelTypeUID(BINDING_ID, "IndustrialDualRelayRelay");
	public static final ChannelTypeUID CHANNEL_TYPE_INDUSTRIAL_DUAL_RELAY_MONOFLOP = new ChannelTypeUID(BINDING_ID, "IndustrialDualRelayMonoflop");
	public static final ChannelTypeUID CHANNEL_TYPE_INDUSTRIAL_QUAD_RELAY_RELAY = new ChannelTypeUID(BINDING_ID, "IndustrialQuadRelayRelay");
	public static final ChannelTypeUID CHANNEL_TYPE_INDUSTRIAL_QUAD_RELAY_MONOFLOP = new ChannelTypeUID(BINDING_ID, "IndustrialQuadRelayMonoflop");
	public static final ChannelTypeUID CHANNEL_TYPE_INDUSTRIAL_QUAD_RELAY_V2_RELAY = new ChannelTypeUID(BINDING_ID, "IndustrialQuadRelayV2Relay");
	public static final ChannelTypeUID CHANNEL_TYPE_INDUSTRIAL_QUAD_RELAY_V2_MONOFLOP = new ChannelTypeUID(BINDING_ID, "IndustrialQuadRelayV2Monoflop");
	public static final ChannelTypeUID CHANNEL_TYPE_IO16_INPUT_PIN = new ChannelTypeUID(BINDING_ID, "IO16InputPin");
	public static final ChannelTypeUID CHANNEL_TYPE_IO16_OUTPUT_PIN = new ChannelTypeUID(BINDING_ID, "IO16OutputPin");
	public static final ChannelTypeUID CHANNEL_TYPE_IO16_MONOFLOP = new ChannelTypeUID(BINDING_ID, "IO16Monoflop");
	public static final ChannelTypeUID CHANNEL_TYPE_IO16_EDGE_COUNT = new ChannelTypeUID(BINDING_ID, "IO16EdgeCount");
	public static final ChannelTypeUID CHANNEL_TYPE_IO16_V2_INPUT_PIN = new ChannelTypeUID(BINDING_ID, "IO16V2InputPin");
	public static final ChannelTypeUID CHANNEL_TYPE_IO16_V2_OUTPUT_PIN = new ChannelTypeUID(BINDING_ID, "IO16V2OutputPin");
	public static final ChannelTypeUID CHANNEL_TYPE_IO16_V2_MONOFLOP = new ChannelTypeUID(BINDING_ID, "IO16V2Monoflop");
	public static final ChannelTypeUID CHANNEL_TYPE_IO16_V2_EDGE_COUNT = new ChannelTypeUID(BINDING_ID, "IO16V2EdgeCount");
	public static final ChannelTypeUID CHANNEL_TYPE_IO4_INPUT_PIN = new ChannelTypeUID(BINDING_ID, "IO4InputPin");
	public static final ChannelTypeUID CHANNEL_TYPE_IO4_OUTPUT_PIN = new ChannelTypeUID(BINDING_ID, "IO4OutputPin");
	public static final ChannelTypeUID CHANNEL_TYPE_IO4_MONOFLOP = new ChannelTypeUID(BINDING_ID, "IO4Monoflop");
	public static final ChannelTypeUID CHANNEL_TYPE_IO4_EDGE_COUNT = new ChannelTypeUID(BINDING_ID, "IO4EdgeCount");
	public static final ChannelTypeUID CHANNEL_TYPE_IO4_V2_INPUT_PIN = new ChannelTypeUID(BINDING_ID, "IO4V2InputPin");
	public static final ChannelTypeUID CHANNEL_TYPE_IO4_V2_OUTPUT_PIN = new ChannelTypeUID(BINDING_ID, "IO4V2OutputPin");
	public static final ChannelTypeUID CHANNEL_TYPE_IO4_V2_MONOFLOP = new ChannelTypeUID(BINDING_ID, "IO4V2Monoflop");
	public static final ChannelTypeUID CHANNEL_TYPE_IO4_V2_EDGE_COUNT = new ChannelTypeUID(BINDING_ID, "IO4V2EdgeCount");
	public static final ChannelTypeUID CHANNEL_TYPE_LCD_128X64_TEXT = new ChannelTypeUID(BINDING_ID, "LCD128x64Text");
	public static final ChannelTypeUID CHANNEL_TYPE_LCD_128X64_CLEAR_DISPLAY = new ChannelTypeUID(BINDING_ID, "LCD128x64ClearDisplay");
	public static final ChannelTypeUID CHANNEL_TYPE_LCD_128X64_DRAW_BUFFERED_FRAME = new ChannelTypeUID(BINDING_ID, "LCD128x64DrawBufferedFrame");
	public static final ChannelTypeUID CHANNEL_TYPE_LCD_16X2_TEXT = new ChannelTypeUID(BINDING_ID, "LCD16x2Text");
	public static final ChannelTypeUID CHANNEL_TYPE_LCD_16X2_CLEAR_DISPLAY = new ChannelTypeUID(BINDING_ID, "LCD16x2ClearDisplay");
	public static final ChannelTypeUID CHANNEL_TYPE_LCD_16X2_BACKLIGHT = new ChannelTypeUID(BINDING_ID, "LCD16x2Backlight");
	public static final ChannelTypeUID CHANNEL_TYPE_LCD_20X4_TEXT = new ChannelTypeUID(BINDING_ID, "LCD20x4Text");
	public static final ChannelTypeUID CHANNEL_TYPE_LCD_20X4_CLEAR_DISPLAY = new ChannelTypeUID(BINDING_ID, "LCD20x4ClearDisplay");
	public static final ChannelTypeUID CHANNEL_TYPE_LCD_20X4_BACKLIGHT = new ChannelTypeUID(BINDING_ID, "LCD20x4Backlight");
	public static final ChannelTypeUID CHANNEL_TYPE_LOAD_CELL_WEIGHT = new ChannelTypeUID(BINDING_ID, "LoadCellWeight");
	public static final ChannelTypeUID CHANNEL_TYPE_LOAD_CELL_TARE = new ChannelTypeUID(BINDING_ID, "LoadCellTare");
	public static final ChannelTypeUID CHANNEL_TYPE_LOAD_CELL_V2_WEIGHT = new ChannelTypeUID(BINDING_ID, "LoadCellV2Weight");
	public static final ChannelTypeUID CHANNEL_TYPE_LOAD_CELL_V2_TARE = new ChannelTypeUID(BINDING_ID, "LoadCellV2Tare");
	public static final ChannelTypeUID CHANNEL_TYPE_MOTION_DETECTOR_V2_INDICATOR = new ChannelTypeUID(BINDING_ID, "MotionDetectorV2Indicator");
	public static final ChannelTypeUID CHANNEL_TYPE_MULTI_TOUCH_ELECTRODE = new ChannelTypeUID(BINDING_ID, "MultiTouchElectrode");
	public static final ChannelTypeUID CHANNEL_TYPE_MULTI_TOUCH_RECALIBRATE = new ChannelTypeUID(BINDING_ID, "MultiTouchRecalibrate");
	public static final ChannelTypeUID CHANNEL_TYPE_MULTI_TOUCH_V2_ELECTRODE = new ChannelTypeUID(BINDING_ID, "MultiTouchV2Electrode");
	public static final ChannelTypeUID CHANNEL_TYPE_MULTI_TOUCH_V2_RECALIBRATE = new ChannelTypeUID(BINDING_ID, "MultiTouchV2Recalibrate");
	public static final ChannelTypeUID CHANNEL_TYPE_OLED_128X64_TEXT = new ChannelTypeUID(BINDING_ID, "OLED128x64Text");
	public static final ChannelTypeUID CHANNEL_TYPE_OLED_128X64_CLEAR_DISPLAY = new ChannelTypeUID(BINDING_ID, "OLED128x64ClearDisplay");
	public static final ChannelTypeUID CHANNEL_TYPE_OLED_128X64_V2_TEXT = new ChannelTypeUID(BINDING_ID, "OLED128x64V2Text");
	public static final ChannelTypeUID CHANNEL_TYPE_OLED_128X64_V2_CLEAR_DISPLAY = new ChannelTypeUID(BINDING_ID, "OLED128x64V2ClearDisplay");
	public static final ChannelTypeUID CHANNEL_TYPE_OLED_128X64_V2_DRAW_BUFFERED_FRAME = new ChannelTypeUID(BINDING_ID, "OLED128x64V2DrawBufferedFrame");
	public static final ChannelTypeUID CHANNEL_TYPE_OLED_64X48_TEXT = new ChannelTypeUID(BINDING_ID, "OLED64x48Text");
	public static final ChannelTypeUID CHANNEL_TYPE_OLED_64X48_CLEAR_DISPLAY = new ChannelTypeUID(BINDING_ID, "OLED64x48ClearDisplay");
	public static final ChannelTypeUID CHANNEL_TYPE_PARTICULATE_MATTER_PM10_CONCENTRATION = new ChannelTypeUID(BINDING_ID, "ParticulateMatterPM10Concentration");
	public static final ChannelTypeUID CHANNEL_TYPE_PARTICULATE_MATTER_PM25_CONCENTRATION = new ChannelTypeUID(BINDING_ID, "ParticulateMatterPM25Concentration");
	public static final ChannelTypeUID CHANNEL_TYPE_PARTICULATE_MATTER_PM100_CONCENTRATION = new ChannelTypeUID(BINDING_ID, "ParticulateMatterPM100Concentration");
	public static final ChannelTypeUID CHANNEL_TYPE_PARTICULATE_MATTER_PART_COUNT_3 = new ChannelTypeUID(BINDING_ID, "ParticulateMatterPartCount3");
	public static final ChannelTypeUID CHANNEL_TYPE_PARTICULATE_MATTER_PART_COUNT_5 = new ChannelTypeUID(BINDING_ID, "ParticulateMatterPartCount5");
	public static final ChannelTypeUID CHANNEL_TYPE_PARTICULATE_MATTER_PART_COUNT_10 = new ChannelTypeUID(BINDING_ID, "ParticulateMatterPartCount10");
	public static final ChannelTypeUID CHANNEL_TYPE_PARTICULATE_MATTER_PART_COUNT_25 = new ChannelTypeUID(BINDING_ID, "ParticulateMatterPartCount25");
	public static final ChannelTypeUID CHANNEL_TYPE_PARTICULATE_MATTER_PART_COUNT_50 = new ChannelTypeUID(BINDING_ID, "ParticulateMatterPartCount50");
	public static final ChannelTypeUID CHANNEL_TYPE_PARTICULATE_MATTER_PART_COUNT_100 = new ChannelTypeUID(BINDING_ID, "ParticulateMatterPartCount100");
	public static final ChannelTypeUID CHANNEL_TYPE_PARTICULATE_MATTER_SENSOR_ENABLED = new ChannelTypeUID(BINDING_ID, "ParticulateMatterSensorEnabled");
	public static final ChannelTypeUID CHANNEL_TYPE_PTC_TEMPERATURE = new ChannelTypeUID(BINDING_ID, "PTCTemperature");
	public static final ChannelTypeUID CHANNEL_TYPE_PTC_SENSOR_CONNECTED = new ChannelTypeUID(BINDING_ID, "PTCSensorConnected");
	public static final ChannelTypeUID CHANNEL_TYPE_PTC_V2_TEMPERATURE = new ChannelTypeUID(BINDING_ID, "PTCV2Temperature");
	public static final ChannelTypeUID CHANNEL_TYPE_PTC_V2_SENSOR_CONNECTED = new ChannelTypeUID(BINDING_ID, "PTCV2SensorConnected");
	public static final ChannelTypeUID CHANNEL_TYPE_REAL_TIME_CLOCK_DATE_TIME = new ChannelTypeUID(BINDING_ID, "RealTimeClockDateTime");
	public static final ChannelTypeUID CHANNEL_TYPE_REAL_TIME_CLOCK_TIMESTAMP = new ChannelTypeUID(BINDING_ID, "RealTimeClockTimestamp");
	public static final ChannelTypeUID CHANNEL_TYPE_REAL_TIME_CLOCK_V2_DATE_TIME = new ChannelTypeUID(BINDING_ID, "RealTimeClockV2DateTime");
	public static final ChannelTypeUID CHANNEL_TYPE_REAL_TIME_CLOCK_V2_TIMESTAMP = new ChannelTypeUID(BINDING_ID, "RealTimeClockV2Timestamp");
	public static final ChannelTypeUID CHANNEL_TYPE_RGB_LED_BUTTON_COLOR = new ChannelTypeUID(BINDING_ID, "RGBLEDButtonColor");
	public static final ChannelTypeUID CHANNEL_TYPE_ROTARY_ENCODER_COUNT = new ChannelTypeUID(BINDING_ID, "RotaryEncoderCount");
	public static final ChannelTypeUID CHANNEL_TYPE_ROTARY_ENCODER_RESET_COUNTER = new ChannelTypeUID(BINDING_ID, "RotaryEncoderResetCounter");
	public static final ChannelTypeUID CHANNEL_TYPE_ROTARY_POTI_V2_POSITION = new ChannelTypeUID(BINDING_ID, "RotaryPotiV2Position");
	public static final ChannelTypeUID CHANNEL_TYPE_SOLID_STATE_RELAY_RELAY = new ChannelTypeUID(BINDING_ID, "SolidStateRelayRelay");
	public static final ChannelTypeUID CHANNEL_TYPE_SOLID_STATE_RELAY_MONOFLOP = new ChannelTypeUID(BINDING_ID, "SolidStateRelayMonoflop");
	public static final ChannelTypeUID CHANNEL_TYPE_SOLID_STATE_RELAY_V2_RELAY = new ChannelTypeUID(BINDING_ID, "SolidStateRelayV2Relay");
	public static final ChannelTypeUID CHANNEL_TYPE_SOLID_STATE_RELAY_V2_MONOFLOP = new ChannelTypeUID(BINDING_ID, "SolidStateRelayV2Monoflop");
	public static final ChannelTypeUID CHANNEL_TYPE_SOUND_INTENSITY_INTENSITY = new ChannelTypeUID(BINDING_ID, "SoundIntensityIntensity");
	public static final ChannelTypeUID CHANNEL_TYPE_SOUND_PRESSURE_LEVEL_SOUND_PRESSURE = new ChannelTypeUID(BINDING_ID, "SoundPressureLevelSoundPressure");
	public static final ChannelTypeUID CHANNEL_TYPE_TEMPERATURE_TEMPERATURE = new ChannelTypeUID(BINDING_ID, "TemperatureTemperature");
	public static final ChannelTypeUID CHANNEL_TYPE_TEMPERATURE_IR_AMBIENT_TEMPERATURE = new ChannelTypeUID(BINDING_ID, "TemperatureIRAmbientTemperature");
	public static final ChannelTypeUID CHANNEL_TYPE_TEMPERATURE_IR_OBJECT_TEMPERATURE = new ChannelTypeUID(BINDING_ID, "TemperatureIRObjectTemperature");
	public static final ChannelTypeUID CHANNEL_TYPE_TEMPERATURE_IR_V2_AMBIENT_TEMPERATURE = new ChannelTypeUID(BINDING_ID, "TemperatureIRV2AmbientTemperature");
	public static final ChannelTypeUID CHANNEL_TYPE_TEMPERATURE_IR_V2_OBJECT_TEMPERATURE = new ChannelTypeUID(BINDING_ID, "TemperatureIRV2ObjectTemperature");
	public static final ChannelTypeUID CHANNEL_TYPE_TEMPERATURE_V2_TEMPERATURE = new ChannelTypeUID(BINDING_ID, "TemperatureV2Temperature");
	public static final ChannelTypeUID CHANNEL_TYPE_UV_LIGHT_UV_INDEX = new ChannelTypeUID(BINDING_ID, "UVLightUVIndex");
	public static final ChannelTypeUID CHANNEL_TYPE_UV_LIGHT_V2_UVA_INTENSITY = new ChannelTypeUID(BINDING_ID, "UVLightV2UVAIntensity");
	public static final ChannelTypeUID CHANNEL_TYPE_UV_LIGHT_V2_UVB_INTENSITY = new ChannelTypeUID(BINDING_ID, "UVLightV2UVBIntensity");
	public static final ChannelTypeUID CHANNEL_TYPE_UV_LIGHT_V2_UV_INDEX = new ChannelTypeUID(BINDING_ID, "UVLightV2UVIndex");
	public static final ChannelTypeUID CHANNEL_TYPE_VOLTAGE_CURRENT_V2_VOLTAGE = new ChannelTypeUID(BINDING_ID, "VoltageCurrentV2Voltage");
	public static final ChannelTypeUID CHANNEL_TYPE_VOLTAGE_CURRENT_V2_CURRENT = new ChannelTypeUID(BINDING_ID, "VoltageCurrentV2Current");
	public static final ChannelTypeUID CHANNEL_TYPE_VOLTAGE_CURRENT_V2_POWER = new ChannelTypeUID(BINDING_ID, "VoltageCurrentV2Power");

    public static final Map<ChannelTypeUID, ThingTypeUID> SUPPORTED_CHANNELS;

    static {
        SUPPORTED_CHANNELS = new HashMap<>();
        SUPPORTED_CHANNELS.put(CHANNEL_TYPE_AIR_QUALITY_HUMIDITY, THING_TYPE_AIR_QUALITY);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_AIR_QUALITY_TEMPERATURE, THING_TYPE_AIR_QUALITY);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_AIR_QUALITY_AIR_PRESSURE, THING_TYPE_AIR_QUALITY);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_AIR_QUALITY_IAQ_INDEX, THING_TYPE_AIR_QUALITY);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_AIR_QUALITY_IAQ_INDEX_ACCURACY, THING_TYPE_AIR_QUALITY);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_AMBIENT_LIGHT_ILLUMINANCE, THING_TYPE_AMBIENT_LIGHT);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_AMBIENT_LIGHT_V2_ILLUMINANCE, THING_TYPE_AMBIENT_LIGHT_V2);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_AMBIENT_LIGHT_V3_ILLUMINANCE, THING_TYPE_AMBIENT_LIGHT_V3);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_ANALOG_IN_V3_VOLTAGE, THING_TYPE_ANALOG_IN_V3);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_BAROMETER_AIR_PRESSURE, THING_TYPE_BAROMETER);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_BAROMETER_ALTITUDE, THING_TYPE_BAROMETER);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_BAROMETER_V2_AIR_PRESSURE, THING_TYPE_BAROMETER_V2);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_BAROMETER_V2_ALTITUDE, THING_TYPE_BAROMETER_V2);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_BAROMETER_V2_TEMPERATURE, THING_TYPE_BAROMETER_V2);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_COLOR_COLOR, THING_TYPE_COLOR);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_COLOR_V2_COLOR, THING_TYPE_COLOR_V2);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_COLOR_V2_ILLUMINANCE, THING_TYPE_COLOR_V2);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_COLOR_V2_COLOR_TEMPERATURE, THING_TYPE_COLOR_V2);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_COLOR_V2_LIGHT, THING_TYPE_COLOR_V2);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_COMPASS_HEADING, THING_TYPE_COMPASS);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_DISTANCE_IR_DISTANCE, THING_TYPE_DISTANCE_IR);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_DISTANCE_IR_V2_DISTANCE, THING_TYPE_DISTANCE_IR_V2);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_DISTANCE_US_DISTANCE, THING_TYPE_DISTANCE_US);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_DISTANCE_US_V2_DISTANCE, THING_TYPE_DISTANCE_US_V2);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_DUAL_RELAY_RELAY, THING_TYPE_DUAL_RELAY);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_DUAL_RELAY_MONOFLOP, THING_TYPE_DUAL_RELAY);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_ENERGY_MONITOR_VOLTAGE, THING_TYPE_ENERGY_MONITOR);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_ENERGY_MONITOR_CURRENT, THING_TYPE_ENERGY_MONITOR);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_ENERGY_MONITOR_ENERGY, THING_TYPE_ENERGY_MONITOR);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_ENERGY_MONITOR_REALPOWER, THING_TYPE_ENERGY_MONITOR);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_ENERGY_MONITOR_APPPOWER, THING_TYPE_ENERGY_MONITOR);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_ENERGY_MONITOR_REACPOWER, THING_TYPE_ENERGY_MONITOR);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_ENERGY_MONITOR_FACTOR, THING_TYPE_ENERGY_MONITOR);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_ENERGY_MONITOR_FREQUENCY, THING_TYPE_ENERGY_MONITOR);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_ENERGY_MONITOR_RESET, THING_TYPE_ENERGY_MONITOR);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_HUMIDITY_HUMIDITY, THING_TYPE_HUMIDITY);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_HUMIDITY_V2_HUMIDITY, THING_TYPE_HUMIDITY_V2);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_HUMIDITY_V2_TEMPERATURE, THING_TYPE_HUMIDITY_V2);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_INDUSTRIAL_ANALOG_OUT_V2_ENABLED, THING_TYPE_INDUSTRIAL_ANALOG_OUT_V2);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_INDUSTRIAL_ANALOG_OUT_V2_VOLTAGE, THING_TYPE_INDUSTRIAL_ANALOG_OUT_V2);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_INDUSTRIAL_ANALOG_OUT_V2_CURRENT, THING_TYPE_INDUSTRIAL_ANALOG_OUT_V2);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_INDUSTRIAL_DIGITAL_IN_4_V2_INPUT, THING_TYPE_INDUSTRIAL_DIGITAL_IN_4_V2);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_INDUSTRIAL_DIGITAL_IN_4_V2_EDGE_COUNT, THING_TYPE_INDUSTRIAL_DIGITAL_IN_4_V2);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_INDUSTRIAL_DUAL_ANALOG_IN_VOLTAGE, THING_TYPE_INDUSTRIAL_DUAL_ANALOG_IN);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_INDUSTRIAL_DUAL_ANALOG_IN_V2_VOLTAGE, THING_TYPE_INDUSTRIAL_DUAL_ANALOG_IN_V2);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_INDUSTRIAL_DUAL_RELAY_RELAY, THING_TYPE_INDUSTRIAL_DUAL_RELAY);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_INDUSTRIAL_DUAL_RELAY_MONOFLOP, THING_TYPE_INDUSTRIAL_DUAL_RELAY);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_INDUSTRIAL_QUAD_RELAY_RELAY, THING_TYPE_INDUSTRIAL_QUAD_RELAY);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_INDUSTRIAL_QUAD_RELAY_MONOFLOP, THING_TYPE_INDUSTRIAL_QUAD_RELAY);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_INDUSTRIAL_QUAD_RELAY_V2_RELAY, THING_TYPE_INDUSTRIAL_QUAD_RELAY_V2);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_INDUSTRIAL_QUAD_RELAY_V2_MONOFLOP, THING_TYPE_INDUSTRIAL_QUAD_RELAY_V2);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_IO16_INPUT_PIN, THING_TYPE_IO16);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_IO16_OUTPUT_PIN, THING_TYPE_IO16);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_IO16_MONOFLOP, THING_TYPE_IO16);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_IO16_EDGE_COUNT, THING_TYPE_IO16);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_IO16_V2_INPUT_PIN, THING_TYPE_IO16_V2);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_IO16_V2_OUTPUT_PIN, THING_TYPE_IO16_V2);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_IO16_V2_MONOFLOP, THING_TYPE_IO16_V2);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_IO16_V2_EDGE_COUNT, THING_TYPE_IO16_V2);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_IO4_INPUT_PIN, THING_TYPE_IO4);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_IO4_OUTPUT_PIN, THING_TYPE_IO4);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_IO4_MONOFLOP, THING_TYPE_IO4);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_IO4_EDGE_COUNT, THING_TYPE_IO4);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_IO4_V2_INPUT_PIN, THING_TYPE_IO4_V2);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_IO4_V2_OUTPUT_PIN, THING_TYPE_IO4_V2);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_IO4_V2_MONOFLOP, THING_TYPE_IO4_V2);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_IO4_V2_EDGE_COUNT, THING_TYPE_IO4_V2);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_LCD_128X64_TEXT, THING_TYPE_LCD_128X64);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_LCD_128X64_CLEAR_DISPLAY, THING_TYPE_LCD_128X64);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_LCD_128X64_DRAW_BUFFERED_FRAME, THING_TYPE_LCD_128X64);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_LCD_16X2_TEXT, THING_TYPE_LCD_16X2);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_LCD_16X2_CLEAR_DISPLAY, THING_TYPE_LCD_16X2);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_LCD_16X2_BACKLIGHT, THING_TYPE_LCD_16X2);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_LCD_20X4_TEXT, THING_TYPE_LCD_20X4);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_LCD_20X4_CLEAR_DISPLAY, THING_TYPE_LCD_20X4);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_LCD_20X4_BACKLIGHT, THING_TYPE_LCD_20X4);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_LOAD_CELL_WEIGHT, THING_TYPE_LOAD_CELL);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_LOAD_CELL_TARE, THING_TYPE_LOAD_CELL);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_LOAD_CELL_V2_WEIGHT, THING_TYPE_LOAD_CELL_V2);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_LOAD_CELL_V2_TARE, THING_TYPE_LOAD_CELL_V2);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_MOTION_DETECTOR_V2_INDICATOR, THING_TYPE_MOTION_DETECTOR_V2);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_MULTI_TOUCH_ELECTRODE, THING_TYPE_MULTI_TOUCH);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_MULTI_TOUCH_RECALIBRATE, THING_TYPE_MULTI_TOUCH);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_MULTI_TOUCH_V2_ELECTRODE, THING_TYPE_MULTI_TOUCH_V2);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_MULTI_TOUCH_V2_RECALIBRATE, THING_TYPE_MULTI_TOUCH_V2);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_OLED_128X64_TEXT, THING_TYPE_OLED_128X64);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_OLED_128X64_CLEAR_DISPLAY, THING_TYPE_OLED_128X64);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_OLED_128X64_V2_TEXT, THING_TYPE_OLED_128X64_V2);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_OLED_128X64_V2_CLEAR_DISPLAY, THING_TYPE_OLED_128X64_V2);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_OLED_128X64_V2_DRAW_BUFFERED_FRAME, THING_TYPE_OLED_128X64_V2);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_OLED_64X48_TEXT, THING_TYPE_OLED_64X48);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_OLED_64X48_CLEAR_DISPLAY, THING_TYPE_OLED_64X48);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_PARTICULATE_MATTER_PM10_CONCENTRATION, THING_TYPE_PARTICULATE_MATTER);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_PARTICULATE_MATTER_PM25_CONCENTRATION, THING_TYPE_PARTICULATE_MATTER);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_PARTICULATE_MATTER_PM100_CONCENTRATION, THING_TYPE_PARTICULATE_MATTER);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_PARTICULATE_MATTER_PART_COUNT_3, THING_TYPE_PARTICULATE_MATTER);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_PARTICULATE_MATTER_PART_COUNT_5, THING_TYPE_PARTICULATE_MATTER);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_PARTICULATE_MATTER_PART_COUNT_10, THING_TYPE_PARTICULATE_MATTER);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_PARTICULATE_MATTER_PART_COUNT_25, THING_TYPE_PARTICULATE_MATTER);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_PARTICULATE_MATTER_PART_COUNT_50, THING_TYPE_PARTICULATE_MATTER);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_PARTICULATE_MATTER_PART_COUNT_100, THING_TYPE_PARTICULATE_MATTER);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_PARTICULATE_MATTER_SENSOR_ENABLED, THING_TYPE_PARTICULATE_MATTER);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_PTC_TEMPERATURE, THING_TYPE_PTC);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_PTC_SENSOR_CONNECTED, THING_TYPE_PTC);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_PTC_V2_TEMPERATURE, THING_TYPE_PTC_V2);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_PTC_V2_SENSOR_CONNECTED, THING_TYPE_PTC_V2);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_REAL_TIME_CLOCK_DATE_TIME, THING_TYPE_REAL_TIME_CLOCK);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_REAL_TIME_CLOCK_TIMESTAMP, THING_TYPE_REAL_TIME_CLOCK);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_REAL_TIME_CLOCK_V2_DATE_TIME, THING_TYPE_REAL_TIME_CLOCK_V2);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_REAL_TIME_CLOCK_V2_TIMESTAMP, THING_TYPE_REAL_TIME_CLOCK_V2);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_RGB_LED_BUTTON_COLOR, THING_TYPE_RGB_LED_BUTTON);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_ROTARY_ENCODER_COUNT, THING_TYPE_ROTARY_ENCODER);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_ROTARY_ENCODER_RESET_COUNTER, THING_TYPE_ROTARY_ENCODER);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_ROTARY_POTI_V2_POSITION, THING_TYPE_ROTARY_POTI_V2);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_SOLID_STATE_RELAY_RELAY, THING_TYPE_SOLID_STATE_RELAY);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_SOLID_STATE_RELAY_MONOFLOP, THING_TYPE_SOLID_STATE_RELAY);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_SOLID_STATE_RELAY_V2_RELAY, THING_TYPE_SOLID_STATE_RELAY_V2);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_SOLID_STATE_RELAY_V2_MONOFLOP, THING_TYPE_SOLID_STATE_RELAY_V2);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_SOUND_INTENSITY_INTENSITY, THING_TYPE_SOUND_INTENSITY);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_SOUND_PRESSURE_LEVEL_SOUND_PRESSURE, THING_TYPE_SOUND_PRESSURE_LEVEL);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_TEMPERATURE_TEMPERATURE, THING_TYPE_TEMPERATURE);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_TEMPERATURE_IR_AMBIENT_TEMPERATURE, THING_TYPE_TEMPERATURE_IR);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_TEMPERATURE_IR_OBJECT_TEMPERATURE, THING_TYPE_TEMPERATURE_IR);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_TEMPERATURE_IR_V2_AMBIENT_TEMPERATURE, THING_TYPE_TEMPERATURE_IR_V2);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_TEMPERATURE_IR_V2_OBJECT_TEMPERATURE, THING_TYPE_TEMPERATURE_IR_V2);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_TEMPERATURE_V2_TEMPERATURE, THING_TYPE_TEMPERATURE_V2);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_UV_LIGHT_UV_INDEX, THING_TYPE_UV_LIGHT);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_UV_LIGHT_V2_UVA_INTENSITY, THING_TYPE_UV_LIGHT_V2);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_UV_LIGHT_V2_UVB_INTENSITY, THING_TYPE_UV_LIGHT_V2);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_UV_LIGHT_V2_UV_INDEX, THING_TYPE_UV_LIGHT_V2);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_VOLTAGE_CURRENT_V2_VOLTAGE, THING_TYPE_VOLTAGE_CURRENT_V2);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_VOLTAGE_CURRENT_V2_CURRENT, THING_TYPE_VOLTAGE_CURRENT_V2);
		SUPPORTED_CHANNELS.put(CHANNEL_TYPE_VOLTAGE_CURRENT_V2_POWER, THING_TYPE_VOLTAGE_CURRENT_V2);
    }

    public static final URI CONFIG_DESCRIPTION_URI_BRICK_DAEMON = URI.create("thing-type:"+THING_TYPE_BRICK_DAEMON.toString());
    public static final URI CONFIG_DESCRIPTION_URI_DC = URI.create("thing-type:"+THING_TYPE_DC.toString());
	public static final URI CONFIG_DESCRIPTION_URI_HAT = URI.create("thing-type:"+THING_TYPE_HAT.toString());
	public static final URI CONFIG_DESCRIPTION_URI_HAT_ZERO = URI.create("thing-type:"+THING_TYPE_HAT_ZERO.toString());
	public static final URI CONFIG_DESCRIPTION_URI_IMU = URI.create("thing-type:"+THING_TYPE_IMU.toString());
	public static final URI CONFIG_DESCRIPTION_URI_IMU_V2 = URI.create("thing-type:"+THING_TYPE_IMU_V2.toString());
	public static final URI CONFIG_DESCRIPTION_URI_MASTER = URI.create("thing-type:"+THING_TYPE_MASTER.toString());
	public static final URI CONFIG_DESCRIPTION_URI_RED = URI.create("thing-type:"+THING_TYPE_RED.toString());
	public static final URI CONFIG_DESCRIPTION_URI_SERVO = URI.create("thing-type:"+THING_TYPE_SERVO.toString());
	public static final URI CONFIG_DESCRIPTION_URI_SILENT_STEPPER = URI.create("thing-type:"+THING_TYPE_SILENT_STEPPER.toString());
	public static final URI CONFIG_DESCRIPTION_URI_STEPPER = URI.create("thing-type:"+THING_TYPE_STEPPER.toString());
	public static final URI CONFIG_DESCRIPTION_URI_ACCELEROMETER = URI.create("thing-type:"+THING_TYPE_ACCELEROMETER.toString());
	public static final URI CONFIG_DESCRIPTION_URI_ACCELEROMETER_V2 = URI.create("thing-type:"+THING_TYPE_ACCELEROMETER_V2.toString());
	public static final URI CONFIG_DESCRIPTION_URI_AIR_QUALITY_HUMIDITY = URI.create("channel-type:"+CHANNEL_TYPE_AIR_QUALITY_HUMIDITY.toString());
	public static final URI CONFIG_DESCRIPTION_URI_AIR_QUALITY_TEMPERATURE = URI.create("channel-type:"+CHANNEL_TYPE_AIR_QUALITY_TEMPERATURE.toString());
	public static final URI CONFIG_DESCRIPTION_URI_AIR_QUALITY_AIR_PRESSURE = URI.create("channel-type:"+CHANNEL_TYPE_AIR_QUALITY_AIR_PRESSURE.toString());
	public static final URI CONFIG_DESCRIPTION_URI_AIR_QUALITY_IAQ_INDEX = URI.create("channel-type:"+CHANNEL_TYPE_AIR_QUALITY_IAQ_INDEX.toString());
	public static final URI CONFIG_DESCRIPTION_URI_AIR_QUALITY_IAQ_INDEX_ACCURACY = URI.create("channel-type:"+CHANNEL_TYPE_AIR_QUALITY_IAQ_INDEX_ACCURACY.toString());
	public static final URI CONFIG_DESCRIPTION_URI_AIR_QUALITY = URI.create("thing-type:"+THING_TYPE_AIR_QUALITY.toString());
	public static final URI CONFIG_DESCRIPTION_URI_AMBIENT_LIGHT_ILLUMINANCE = URI.create("channel-type:"+CHANNEL_TYPE_AMBIENT_LIGHT_ILLUMINANCE.toString());
	public static final URI CONFIG_DESCRIPTION_URI_AMBIENT_LIGHT = URI.create("thing-type:"+THING_TYPE_AMBIENT_LIGHT.toString());
	public static final URI CONFIG_DESCRIPTION_URI_AMBIENT_LIGHT_V2_ILLUMINANCE = URI.create("channel-type:"+CHANNEL_TYPE_AMBIENT_LIGHT_V2_ILLUMINANCE.toString());
	public static final URI CONFIG_DESCRIPTION_URI_AMBIENT_LIGHT_V2 = URI.create("thing-type:"+THING_TYPE_AMBIENT_LIGHT_V2.toString());
	public static final URI CONFIG_DESCRIPTION_URI_AMBIENT_LIGHT_V3_ILLUMINANCE = URI.create("channel-type:"+CHANNEL_TYPE_AMBIENT_LIGHT_V3_ILLUMINANCE.toString());
	public static final URI CONFIG_DESCRIPTION_URI_AMBIENT_LIGHT_V3 = URI.create("thing-type:"+THING_TYPE_AMBIENT_LIGHT_V3.toString());
	public static final URI CONFIG_DESCRIPTION_URI_ANALOG_IN = URI.create("thing-type:"+THING_TYPE_ANALOG_IN.toString());
	public static final URI CONFIG_DESCRIPTION_URI_ANALOG_IN_V2 = URI.create("thing-type:"+THING_TYPE_ANALOG_IN_V2.toString());
	public static final URI CONFIG_DESCRIPTION_URI_ANALOG_IN_V3_VOLTAGE = URI.create("channel-type:"+CHANNEL_TYPE_ANALOG_IN_V3_VOLTAGE.toString());
	public static final URI CONFIG_DESCRIPTION_URI_ANALOG_IN_V3 = URI.create("thing-type:"+THING_TYPE_ANALOG_IN_V3.toString());
	public static final URI CONFIG_DESCRIPTION_URI_ANALOG_OUT = URI.create("thing-type:"+THING_TYPE_ANALOG_OUT.toString());
	public static final URI CONFIG_DESCRIPTION_URI_ANALOG_OUT_V2 = URI.create("thing-type:"+THING_TYPE_ANALOG_OUT_V2.toString());
	public static final URI CONFIG_DESCRIPTION_URI_ANALOG_OUT_V3 = URI.create("thing-type:"+THING_TYPE_ANALOG_OUT_V3.toString());
	public static final URI CONFIG_DESCRIPTION_URI_BAROMETER_AIR_PRESSURE = URI.create("channel-type:"+CHANNEL_TYPE_BAROMETER_AIR_PRESSURE.toString());
	public static final URI CONFIG_DESCRIPTION_URI_BAROMETER_ALTITUDE = URI.create("channel-type:"+CHANNEL_TYPE_BAROMETER_ALTITUDE.toString());
	public static final URI CONFIG_DESCRIPTION_URI_BAROMETER = URI.create("thing-type:"+THING_TYPE_BAROMETER.toString());
	public static final URI CONFIG_DESCRIPTION_URI_BAROMETER_V2_AIR_PRESSURE = URI.create("channel-type:"+CHANNEL_TYPE_BAROMETER_V2_AIR_PRESSURE.toString());
	public static final URI CONFIG_DESCRIPTION_URI_BAROMETER_V2_ALTITUDE = URI.create("channel-type:"+CHANNEL_TYPE_BAROMETER_V2_ALTITUDE.toString());
	public static final URI CONFIG_DESCRIPTION_URI_BAROMETER_V2_TEMPERATURE = URI.create("channel-type:"+CHANNEL_TYPE_BAROMETER_V2_TEMPERATURE.toString());
	public static final URI CONFIG_DESCRIPTION_URI_BAROMETER_V2 = URI.create("thing-type:"+THING_TYPE_BAROMETER_V2.toString());
	public static final URI CONFIG_DESCRIPTION_URI_CAN = URI.create("thing-type:"+THING_TYPE_CAN.toString());
	public static final URI CONFIG_DESCRIPTION_URI_CAN_V2 = URI.create("thing-type:"+THING_TYPE_CAN_V2.toString());
	public static final URI CONFIG_DESCRIPTION_URI_CO2 = URI.create("thing-type:"+THING_TYPE_CO2.toString());
	public static final URI CONFIG_DESCRIPTION_URI_CO2_V2 = URI.create("thing-type:"+THING_TYPE_CO2_V2.toString());
	public static final URI CONFIG_DESCRIPTION_URI_COLOR_COLOR = URI.create("channel-type:"+CHANNEL_TYPE_COLOR_COLOR.toString());
	public static final URI CONFIG_DESCRIPTION_URI_COLOR = URI.create("thing-type:"+THING_TYPE_COLOR.toString());
	public static final URI CONFIG_DESCRIPTION_URI_COLOR_V2_COLOR = URI.create("channel-type:"+CHANNEL_TYPE_COLOR_V2_COLOR.toString());
	public static final URI CONFIG_DESCRIPTION_URI_COLOR_V2_ILLUMINANCE = URI.create("channel-type:"+CHANNEL_TYPE_COLOR_V2_ILLUMINANCE.toString());
	public static final URI CONFIG_DESCRIPTION_URI_COLOR_V2_COLOR_TEMPERATURE = URI.create("channel-type:"+CHANNEL_TYPE_COLOR_V2_COLOR_TEMPERATURE.toString());
	public static final URI CONFIG_DESCRIPTION_URI_COLOR_V2_LIGHT = URI.create("channel-type:"+CHANNEL_TYPE_COLOR_V2_LIGHT.toString());
	public static final URI CONFIG_DESCRIPTION_URI_COLOR_V2 = URI.create("thing-type:"+THING_TYPE_COLOR_V2.toString());
	public static final URI CONFIG_DESCRIPTION_URI_COMPASS_HEADING = URI.create("channel-type:"+CHANNEL_TYPE_COMPASS_HEADING.toString());
	public static final URI CONFIG_DESCRIPTION_URI_COMPASS = URI.create("thing-type:"+THING_TYPE_COMPASS.toString());
	public static final URI CONFIG_DESCRIPTION_URI_CURRENT12 = URI.create("thing-type:"+THING_TYPE_CURRENT12.toString());
	public static final URI CONFIG_DESCRIPTION_URI_CURRENT25 = URI.create("thing-type:"+THING_TYPE_CURRENT25.toString());
	public static final URI CONFIG_DESCRIPTION_URI_DISTANCE_IR_DISTANCE = URI.create("channel-type:"+CHANNEL_TYPE_DISTANCE_IR_DISTANCE.toString());
	public static final URI CONFIG_DESCRIPTION_URI_DISTANCE_IR = URI.create("thing-type:"+THING_TYPE_DISTANCE_IR.toString());
	public static final URI CONFIG_DESCRIPTION_URI_DISTANCE_IR_V2_DISTANCE = URI.create("channel-type:"+CHANNEL_TYPE_DISTANCE_IR_V2_DISTANCE.toString());
	public static final URI CONFIG_DESCRIPTION_URI_DISTANCE_IR_V2 = URI.create("thing-type:"+THING_TYPE_DISTANCE_IR_V2.toString());
	public static final URI CONFIG_DESCRIPTION_URI_DISTANCE_US_DISTANCE = URI.create("channel-type:"+CHANNEL_TYPE_DISTANCE_US_DISTANCE.toString());
	public static final URI CONFIG_DESCRIPTION_URI_DISTANCE_US = URI.create("thing-type:"+THING_TYPE_DISTANCE_US.toString());
	public static final URI CONFIG_DESCRIPTION_URI_DISTANCE_US_V2_DISTANCE = URI.create("channel-type:"+CHANNEL_TYPE_DISTANCE_US_V2_DISTANCE.toString());
	public static final URI CONFIG_DESCRIPTION_URI_DISTANCE_US_V2 = URI.create("thing-type:"+THING_TYPE_DISTANCE_US_V2.toString());
	public static final URI CONFIG_DESCRIPTION_URI_DMX = URI.create("thing-type:"+THING_TYPE_DMX.toString());
	public static final URI CONFIG_DESCRIPTION_URI_DUAL_BUTTON = URI.create("thing-type:"+THING_TYPE_DUAL_BUTTON.toString());
	public static final URI CONFIG_DESCRIPTION_URI_DUAL_BUTTON_V2 = URI.create("thing-type:"+THING_TYPE_DUAL_BUTTON_V2.toString());
	public static final URI CONFIG_DESCRIPTION_URI_DUAL_RELAY_RELAY = URI.create("channel-type:"+CHANNEL_TYPE_DUAL_RELAY_RELAY.toString());
	public static final URI CONFIG_DESCRIPTION_URI_DUAL_RELAY_MONOFLOP = URI.create("channel-type:"+CHANNEL_TYPE_DUAL_RELAY_MONOFLOP.toString());
	public static final URI CONFIG_DESCRIPTION_URI_DUAL_RELAY = URI.create("thing-type:"+THING_TYPE_DUAL_RELAY.toString());
	public static final URI CONFIG_DESCRIPTION_URI_DUST_DETECTOR = URI.create("thing-type:"+THING_TYPE_DUST_DETECTOR.toString());
	public static final URI CONFIG_DESCRIPTION_URI_E_PAPER_296X128 = URI.create("thing-type:"+THING_TYPE_E_PAPER_296X128.toString());
	public static final URI CONFIG_DESCRIPTION_URI_ENERGY_MONITOR_VOLTAGE = URI.create("channel-type:"+CHANNEL_TYPE_ENERGY_MONITOR_VOLTAGE.toString());
	public static final URI CONFIG_DESCRIPTION_URI_ENERGY_MONITOR_CURRENT = URI.create("channel-type:"+CHANNEL_TYPE_ENERGY_MONITOR_CURRENT.toString());
	public static final URI CONFIG_DESCRIPTION_URI_ENERGY_MONITOR_ENERGY = URI.create("channel-type:"+CHANNEL_TYPE_ENERGY_MONITOR_ENERGY.toString());
	public static final URI CONFIG_DESCRIPTION_URI_ENERGY_MONITOR_REALPOWER = URI.create("channel-type:"+CHANNEL_TYPE_ENERGY_MONITOR_REALPOWER.toString());
	public static final URI CONFIG_DESCRIPTION_URI_ENERGY_MONITOR_APPPOWER = URI.create("channel-type:"+CHANNEL_TYPE_ENERGY_MONITOR_APPPOWER.toString());
	public static final URI CONFIG_DESCRIPTION_URI_ENERGY_MONITOR_REACPOWER = URI.create("channel-type:"+CHANNEL_TYPE_ENERGY_MONITOR_REACPOWER.toString());
	public static final URI CONFIG_DESCRIPTION_URI_ENERGY_MONITOR_FACTOR = URI.create("channel-type:"+CHANNEL_TYPE_ENERGY_MONITOR_FACTOR.toString());
	public static final URI CONFIG_DESCRIPTION_URI_ENERGY_MONITOR_FREQUENCY = URI.create("channel-type:"+CHANNEL_TYPE_ENERGY_MONITOR_FREQUENCY.toString());
	public static final URI CONFIG_DESCRIPTION_URI_ENERGY_MONITOR_RESET = URI.create("channel-type:"+CHANNEL_TYPE_ENERGY_MONITOR_RESET.toString());
	public static final URI CONFIG_DESCRIPTION_URI_ENERGY_MONITOR = URI.create("thing-type:"+THING_TYPE_ENERGY_MONITOR.toString());
	public static final URI CONFIG_DESCRIPTION_URI_GPS = URI.create("thing-type:"+THING_TYPE_GPS.toString());
	public static final URI CONFIG_DESCRIPTION_URI_GPS_V2 = URI.create("thing-type:"+THING_TYPE_GPS_V2.toString());
	public static final URI CONFIG_DESCRIPTION_URI_HALL_EFFECT = URI.create("thing-type:"+THING_TYPE_HALL_EFFECT.toString());
	public static final URI CONFIG_DESCRIPTION_URI_HALL_EFFECT_V2 = URI.create("thing-type:"+THING_TYPE_HALL_EFFECT_V2.toString());
	public static final URI CONFIG_DESCRIPTION_URI_HUMIDITY_HUMIDITY = URI.create("channel-type:"+CHANNEL_TYPE_HUMIDITY_HUMIDITY.toString());
	public static final URI CONFIG_DESCRIPTION_URI_HUMIDITY = URI.create("thing-type:"+THING_TYPE_HUMIDITY.toString());
	public static final URI CONFIG_DESCRIPTION_URI_HUMIDITY_V2_HUMIDITY = URI.create("channel-type:"+CHANNEL_TYPE_HUMIDITY_V2_HUMIDITY.toString());
	public static final URI CONFIG_DESCRIPTION_URI_HUMIDITY_V2_TEMPERATURE = URI.create("channel-type:"+CHANNEL_TYPE_HUMIDITY_V2_TEMPERATURE.toString());
	public static final URI CONFIG_DESCRIPTION_URI_HUMIDITY_V2 = URI.create("thing-type:"+THING_TYPE_HUMIDITY_V2.toString());
	public static final URI CONFIG_DESCRIPTION_URI_INDUSTRIAL_ANALOG_OUT = URI.create("thing-type:"+THING_TYPE_INDUSTRIAL_ANALOG_OUT.toString());
	public static final URI CONFIG_DESCRIPTION_URI_INDUSTRIAL_ANALOG_OUT_V2_ENABLED = URI.create("channel-type:"+CHANNEL_TYPE_INDUSTRIAL_ANALOG_OUT_V2_ENABLED.toString());
	public static final URI CONFIG_DESCRIPTION_URI_INDUSTRIAL_ANALOG_OUT_V2_VOLTAGE = URI.create("channel-type:"+CHANNEL_TYPE_INDUSTRIAL_ANALOG_OUT_V2_VOLTAGE.toString());
	public static final URI CONFIG_DESCRIPTION_URI_INDUSTRIAL_ANALOG_OUT_V2_CURRENT = URI.create("channel-type:"+CHANNEL_TYPE_INDUSTRIAL_ANALOG_OUT_V2_CURRENT.toString());
	public static final URI CONFIG_DESCRIPTION_URI_INDUSTRIAL_ANALOG_OUT_V2 = URI.create("thing-type:"+THING_TYPE_INDUSTRIAL_ANALOG_OUT_V2.toString());
	public static final URI CONFIG_DESCRIPTION_URI_INDUSTRIAL_COUNTER = URI.create("thing-type:"+THING_TYPE_INDUSTRIAL_COUNTER.toString());
	public static final URI CONFIG_DESCRIPTION_URI_INDUSTRIAL_DIGITAL_IN_4 = URI.create("thing-type:"+THING_TYPE_INDUSTRIAL_DIGITAL_IN_4.toString());
	public static final URI CONFIG_DESCRIPTION_URI_INDUSTRIAL_DIGITAL_IN_4_V2_INPUT = URI.create("channel-type:"+CHANNEL_TYPE_INDUSTRIAL_DIGITAL_IN_4_V2_INPUT.toString());
	public static final URI CONFIG_DESCRIPTION_URI_INDUSTRIAL_DIGITAL_IN_4_V2_EDGE_COUNT = URI.create("channel-type:"+CHANNEL_TYPE_INDUSTRIAL_DIGITAL_IN_4_V2_EDGE_COUNT.toString());
	public static final URI CONFIG_DESCRIPTION_URI_INDUSTRIAL_DIGITAL_IN_4_V2 = URI.create("thing-type:"+THING_TYPE_INDUSTRIAL_DIGITAL_IN_4_V2.toString());
	public static final URI CONFIG_DESCRIPTION_URI_INDUSTRIAL_DIGITAL_OUT_4 = URI.create("thing-type:"+THING_TYPE_INDUSTRIAL_DIGITAL_OUT_4.toString());
	public static final URI CONFIG_DESCRIPTION_URI_INDUSTRIAL_DIGITAL_OUT_4_V2 = URI.create("thing-type:"+THING_TYPE_INDUSTRIAL_DIGITAL_OUT_4_V2.toString());
	public static final URI CONFIG_DESCRIPTION_URI_INDUSTRIAL_DUAL_0_20MA = URI.create("thing-type:"+THING_TYPE_INDUSTRIAL_DUAL_0_20MA.toString());
	public static final URI CONFIG_DESCRIPTION_URI_INDUSTRIAL_DUAL_0_20MA_V2 = URI.create("thing-type:"+THING_TYPE_INDUSTRIAL_DUAL_0_20MA_V2.toString());
	public static final URI CONFIG_DESCRIPTION_URI_INDUSTRIAL_DUAL_ANALOG_IN_VOLTAGE = URI.create("channel-type:"+CHANNEL_TYPE_INDUSTRIAL_DUAL_ANALOG_IN_VOLTAGE.toString());
	public static final URI CONFIG_DESCRIPTION_URI_INDUSTRIAL_DUAL_ANALOG_IN = URI.create("thing-type:"+THING_TYPE_INDUSTRIAL_DUAL_ANALOG_IN.toString());
	public static final URI CONFIG_DESCRIPTION_URI_INDUSTRIAL_DUAL_ANALOG_IN_V2_VOLTAGE = URI.create("channel-type:"+CHANNEL_TYPE_INDUSTRIAL_DUAL_ANALOG_IN_V2_VOLTAGE.toString());
	public static final URI CONFIG_DESCRIPTION_URI_INDUSTRIAL_DUAL_ANALOG_IN_V2 = URI.create("thing-type:"+THING_TYPE_INDUSTRIAL_DUAL_ANALOG_IN_V2.toString());
	public static final URI CONFIG_DESCRIPTION_URI_INDUSTRIAL_DUAL_RELAY_RELAY = URI.create("channel-type:"+CHANNEL_TYPE_INDUSTRIAL_DUAL_RELAY_RELAY.toString());
	public static final URI CONFIG_DESCRIPTION_URI_INDUSTRIAL_DUAL_RELAY_MONOFLOP = URI.create("channel-type:"+CHANNEL_TYPE_INDUSTRIAL_DUAL_RELAY_MONOFLOP.toString());
	public static final URI CONFIG_DESCRIPTION_URI_INDUSTRIAL_DUAL_RELAY = URI.create("thing-type:"+THING_TYPE_INDUSTRIAL_DUAL_RELAY.toString());
	public static final URI CONFIG_DESCRIPTION_URI_INDUSTRIAL_QUAD_RELAY_RELAY = URI.create("channel-type:"+CHANNEL_TYPE_INDUSTRIAL_QUAD_RELAY_RELAY.toString());
	public static final URI CONFIG_DESCRIPTION_URI_INDUSTRIAL_QUAD_RELAY_MONOFLOP = URI.create("channel-type:"+CHANNEL_TYPE_INDUSTRIAL_QUAD_RELAY_MONOFLOP.toString());
	public static final URI CONFIG_DESCRIPTION_URI_INDUSTRIAL_QUAD_RELAY = URI.create("thing-type:"+THING_TYPE_INDUSTRIAL_QUAD_RELAY.toString());
	public static final URI CONFIG_DESCRIPTION_URI_INDUSTRIAL_QUAD_RELAY_V2_RELAY = URI.create("channel-type:"+CHANNEL_TYPE_INDUSTRIAL_QUAD_RELAY_V2_RELAY.toString());
	public static final URI CONFIG_DESCRIPTION_URI_INDUSTRIAL_QUAD_RELAY_V2_MONOFLOP = URI.create("channel-type:"+CHANNEL_TYPE_INDUSTRIAL_QUAD_RELAY_V2_MONOFLOP.toString());
	public static final URI CONFIG_DESCRIPTION_URI_INDUSTRIAL_QUAD_RELAY_V2 = URI.create("thing-type:"+THING_TYPE_INDUSTRIAL_QUAD_RELAY_V2.toString());
	public static final URI CONFIG_DESCRIPTION_URI_IO16_INPUT_PIN = URI.create("channel-type:"+CHANNEL_TYPE_IO16_INPUT_PIN.toString());
	public static final URI CONFIG_DESCRIPTION_URI_IO16_OUTPUT_PIN = URI.create("channel-type:"+CHANNEL_TYPE_IO16_OUTPUT_PIN.toString());
	public static final URI CONFIG_DESCRIPTION_URI_IO16_MONOFLOP = URI.create("channel-type:"+CHANNEL_TYPE_IO16_MONOFLOP.toString());
	public static final URI CONFIG_DESCRIPTION_URI_IO16_EDGE_COUNT = URI.create("channel-type:"+CHANNEL_TYPE_IO16_EDGE_COUNT.toString());
	public static final URI CONFIG_DESCRIPTION_URI_IO16 = URI.create("thing-type:"+THING_TYPE_IO16.toString());
	public static final URI CONFIG_DESCRIPTION_URI_IO16_V2_INPUT_PIN = URI.create("channel-type:"+CHANNEL_TYPE_IO16_V2_INPUT_PIN.toString());
	public static final URI CONFIG_DESCRIPTION_URI_IO16_V2_OUTPUT_PIN = URI.create("channel-type:"+CHANNEL_TYPE_IO16_V2_OUTPUT_PIN.toString());
	public static final URI CONFIG_DESCRIPTION_URI_IO16_V2_MONOFLOP = URI.create("channel-type:"+CHANNEL_TYPE_IO16_V2_MONOFLOP.toString());
	public static final URI CONFIG_DESCRIPTION_URI_IO16_V2_EDGE_COUNT = URI.create("channel-type:"+CHANNEL_TYPE_IO16_V2_EDGE_COUNT.toString());
	public static final URI CONFIG_DESCRIPTION_URI_IO16_V2 = URI.create("thing-type:"+THING_TYPE_IO16_V2.toString());
	public static final URI CONFIG_DESCRIPTION_URI_IO4_INPUT_PIN = URI.create("channel-type:"+CHANNEL_TYPE_IO4_INPUT_PIN.toString());
	public static final URI CONFIG_DESCRIPTION_URI_IO4_OUTPUT_PIN = URI.create("channel-type:"+CHANNEL_TYPE_IO4_OUTPUT_PIN.toString());
	public static final URI CONFIG_DESCRIPTION_URI_IO4_MONOFLOP = URI.create("channel-type:"+CHANNEL_TYPE_IO4_MONOFLOP.toString());
	public static final URI CONFIG_DESCRIPTION_URI_IO4_EDGE_COUNT = URI.create("channel-type:"+CHANNEL_TYPE_IO4_EDGE_COUNT.toString());
	public static final URI CONFIG_DESCRIPTION_URI_IO4 = URI.create("thing-type:"+THING_TYPE_IO4.toString());
	public static final URI CONFIG_DESCRIPTION_URI_IO4_V2_INPUT_PIN = URI.create("channel-type:"+CHANNEL_TYPE_IO4_V2_INPUT_PIN.toString());
	public static final URI CONFIG_DESCRIPTION_URI_IO4_V2_OUTPUT_PIN = URI.create("channel-type:"+CHANNEL_TYPE_IO4_V2_OUTPUT_PIN.toString());
	public static final URI CONFIG_DESCRIPTION_URI_IO4_V2_MONOFLOP = URI.create("channel-type:"+CHANNEL_TYPE_IO4_V2_MONOFLOP.toString());
	public static final URI CONFIG_DESCRIPTION_URI_IO4_V2_EDGE_COUNT = URI.create("channel-type:"+CHANNEL_TYPE_IO4_V2_EDGE_COUNT.toString());
	public static final URI CONFIG_DESCRIPTION_URI_IO4_V2 = URI.create("thing-type:"+THING_TYPE_IO4_V2.toString());
	public static final URI CONFIG_DESCRIPTION_URI_ISOLATOR = URI.create("thing-type:"+THING_TYPE_ISOLATOR.toString());
	public static final URI CONFIG_DESCRIPTION_URI_JOYSTICK = URI.create("thing-type:"+THING_TYPE_JOYSTICK.toString());
	public static final URI CONFIG_DESCRIPTION_URI_JOYSTICK_V2 = URI.create("thing-type:"+THING_TYPE_JOYSTICK_V2.toString());
	public static final URI CONFIG_DESCRIPTION_URI_LASER_RANGE_FINDER = URI.create("thing-type:"+THING_TYPE_LASER_RANGE_FINDER.toString());
	public static final URI CONFIG_DESCRIPTION_URI_LASER_RANGE_FINDER_V2 = URI.create("thing-type:"+THING_TYPE_LASER_RANGE_FINDER_V2.toString());
	public static final URI CONFIG_DESCRIPTION_URI_LCD_128X64_TEXT = URI.create("channel-type:"+CHANNEL_TYPE_LCD_128X64_TEXT.toString());
	public static final URI CONFIG_DESCRIPTION_URI_LCD_128X64_CLEAR_DISPLAY = URI.create("channel-type:"+CHANNEL_TYPE_LCD_128X64_CLEAR_DISPLAY.toString());
	public static final URI CONFIG_DESCRIPTION_URI_LCD_128X64_DRAW_BUFFERED_FRAME = URI.create("channel-type:"+CHANNEL_TYPE_LCD_128X64_DRAW_BUFFERED_FRAME.toString());
	public static final URI CONFIG_DESCRIPTION_URI_LCD_128X64 = URI.create("thing-type:"+THING_TYPE_LCD_128X64.toString());
	public static final URI CONFIG_DESCRIPTION_URI_LCD_16X2_TEXT = URI.create("channel-type:"+CHANNEL_TYPE_LCD_16X2_TEXT.toString());
	public static final URI CONFIG_DESCRIPTION_URI_LCD_16X2_CLEAR_DISPLAY = URI.create("channel-type:"+CHANNEL_TYPE_LCD_16X2_CLEAR_DISPLAY.toString());
	public static final URI CONFIG_DESCRIPTION_URI_LCD_16X2_BACKLIGHT = URI.create("channel-type:"+CHANNEL_TYPE_LCD_16X2_BACKLIGHT.toString());
	public static final URI CONFIG_DESCRIPTION_URI_LCD_16X2 = URI.create("thing-type:"+THING_TYPE_LCD_16X2.toString());
	public static final URI CONFIG_DESCRIPTION_URI_LCD_20X4_TEXT = URI.create("channel-type:"+CHANNEL_TYPE_LCD_20X4_TEXT.toString());
	public static final URI CONFIG_DESCRIPTION_URI_LCD_20X4_CLEAR_DISPLAY = URI.create("channel-type:"+CHANNEL_TYPE_LCD_20X4_CLEAR_DISPLAY.toString());
	public static final URI CONFIG_DESCRIPTION_URI_LCD_20X4_BACKLIGHT = URI.create("channel-type:"+CHANNEL_TYPE_LCD_20X4_BACKLIGHT.toString());
	public static final URI CONFIG_DESCRIPTION_URI_LCD_20X4 = URI.create("thing-type:"+THING_TYPE_LCD_20X4.toString());
	public static final URI CONFIG_DESCRIPTION_URI_LED_STRIP = URI.create("thing-type:"+THING_TYPE_LED_STRIP.toString());
	public static final URI CONFIG_DESCRIPTION_URI_LED_STRIP_V2 = URI.create("thing-type:"+THING_TYPE_LED_STRIP_V2.toString());
	public static final URI CONFIG_DESCRIPTION_URI_LINE = URI.create("thing-type:"+THING_TYPE_LINE.toString());
	public static final URI CONFIG_DESCRIPTION_URI_LINEAR_POTI = URI.create("thing-type:"+THING_TYPE_LINEAR_POTI.toString());
	public static final URI CONFIG_DESCRIPTION_URI_LINEAR_POTI_V2 = URI.create("thing-type:"+THING_TYPE_LINEAR_POTI_V2.toString());
	public static final URI CONFIG_DESCRIPTION_URI_LOAD_CELL_WEIGHT = URI.create("channel-type:"+CHANNEL_TYPE_LOAD_CELL_WEIGHT.toString());
	public static final URI CONFIG_DESCRIPTION_URI_LOAD_CELL_TARE = URI.create("channel-type:"+CHANNEL_TYPE_LOAD_CELL_TARE.toString());
	public static final URI CONFIG_DESCRIPTION_URI_LOAD_CELL = URI.create("thing-type:"+THING_TYPE_LOAD_CELL.toString());
	public static final URI CONFIG_DESCRIPTION_URI_LOAD_CELL_V2_WEIGHT = URI.create("channel-type:"+CHANNEL_TYPE_LOAD_CELL_V2_WEIGHT.toString());
	public static final URI CONFIG_DESCRIPTION_URI_LOAD_CELL_V2_TARE = URI.create("channel-type:"+CHANNEL_TYPE_LOAD_CELL_V2_TARE.toString());
	public static final URI CONFIG_DESCRIPTION_URI_LOAD_CELL_V2 = URI.create("thing-type:"+THING_TYPE_LOAD_CELL_V2.toString());
	public static final URI CONFIG_DESCRIPTION_URI_MOISTURE = URI.create("thing-type:"+THING_TYPE_MOISTURE.toString());
	public static final URI CONFIG_DESCRIPTION_URI_MOTION_DETECTOR = URI.create("thing-type:"+THING_TYPE_MOTION_DETECTOR.toString());
	public static final URI CONFIG_DESCRIPTION_URI_MOTION_DETECTOR_V2_INDICATOR = URI.create("channel-type:"+CHANNEL_TYPE_MOTION_DETECTOR_V2_INDICATOR.toString());
	public static final URI CONFIG_DESCRIPTION_URI_MOTION_DETECTOR_V2 = URI.create("thing-type:"+THING_TYPE_MOTION_DETECTOR_V2.toString());
	public static final URI CONFIG_DESCRIPTION_URI_MOTORIZED_LINEAR_POTI = URI.create("thing-type:"+THING_TYPE_MOTORIZED_LINEAR_POTI.toString());
	public static final URI CONFIG_DESCRIPTION_URI_MULTI_TOUCH_ELECTRODE = URI.create("channel-type:"+CHANNEL_TYPE_MULTI_TOUCH_ELECTRODE.toString());
	public static final URI CONFIG_DESCRIPTION_URI_MULTI_TOUCH_RECALIBRATE = URI.create("channel-type:"+CHANNEL_TYPE_MULTI_TOUCH_RECALIBRATE.toString());
	public static final URI CONFIG_DESCRIPTION_URI_MULTI_TOUCH = URI.create("thing-type:"+THING_TYPE_MULTI_TOUCH.toString());
	public static final URI CONFIG_DESCRIPTION_URI_MULTI_TOUCH_V2_ELECTRODE = URI.create("channel-type:"+CHANNEL_TYPE_MULTI_TOUCH_V2_ELECTRODE.toString());
	public static final URI CONFIG_DESCRIPTION_URI_MULTI_TOUCH_V2_RECALIBRATE = URI.create("channel-type:"+CHANNEL_TYPE_MULTI_TOUCH_V2_RECALIBRATE.toString());
	public static final URI CONFIG_DESCRIPTION_URI_MULTI_TOUCH_V2 = URI.create("thing-type:"+THING_TYPE_MULTI_TOUCH_V2.toString());
	public static final URI CONFIG_DESCRIPTION_URI_NFC = URI.create("thing-type:"+THING_TYPE_NFC.toString());
	public static final URI CONFIG_DESCRIPTION_URI_NFC_RFID = URI.create("thing-type:"+THING_TYPE_NFC_RFID.toString());
	public static final URI CONFIG_DESCRIPTION_URI_OLED_128X64_TEXT = URI.create("channel-type:"+CHANNEL_TYPE_OLED_128X64_TEXT.toString());
	public static final URI CONFIG_DESCRIPTION_URI_OLED_128X64_CLEAR_DISPLAY = URI.create("channel-type:"+CHANNEL_TYPE_OLED_128X64_CLEAR_DISPLAY.toString());
	public static final URI CONFIG_DESCRIPTION_URI_OLED_128X64 = URI.create("thing-type:"+THING_TYPE_OLED_128X64.toString());
	public static final URI CONFIG_DESCRIPTION_URI_OLED_128X64_V2_TEXT = URI.create("channel-type:"+CHANNEL_TYPE_OLED_128X64_V2_TEXT.toString());
	public static final URI CONFIG_DESCRIPTION_URI_OLED_128X64_V2_CLEAR_DISPLAY = URI.create("channel-type:"+CHANNEL_TYPE_OLED_128X64_V2_CLEAR_DISPLAY.toString());
	public static final URI CONFIG_DESCRIPTION_URI_OLED_128X64_V2_DRAW_BUFFERED_FRAME = URI.create("channel-type:"+CHANNEL_TYPE_OLED_128X64_V2_DRAW_BUFFERED_FRAME.toString());
	public static final URI CONFIG_DESCRIPTION_URI_OLED_128X64_V2 = URI.create("thing-type:"+THING_TYPE_OLED_128X64_V2.toString());
	public static final URI CONFIG_DESCRIPTION_URI_OLED_64X48_TEXT = URI.create("channel-type:"+CHANNEL_TYPE_OLED_64X48_TEXT.toString());
	public static final URI CONFIG_DESCRIPTION_URI_OLED_64X48_CLEAR_DISPLAY = URI.create("channel-type:"+CHANNEL_TYPE_OLED_64X48_CLEAR_DISPLAY.toString());
	public static final URI CONFIG_DESCRIPTION_URI_OLED_64X48 = URI.create("thing-type:"+THING_TYPE_OLED_64X48.toString());
	public static final URI CONFIG_DESCRIPTION_URI_ONE_WIRE = URI.create("thing-type:"+THING_TYPE_ONE_WIRE.toString());
	public static final URI CONFIG_DESCRIPTION_URI_OUTDOOR_WEATHER = URI.create("thing-type:"+THING_TYPE_OUTDOOR_WEATHER.toString());
	public static final URI CONFIG_DESCRIPTION_URI_PARTICULATE_MATTER_PM10_CONCENTRATION = URI.create("channel-type:"+CHANNEL_TYPE_PARTICULATE_MATTER_PM10_CONCENTRATION.toString());
	public static final URI CONFIG_DESCRIPTION_URI_PARTICULATE_MATTER_PM25_CONCENTRATION = URI.create("channel-type:"+CHANNEL_TYPE_PARTICULATE_MATTER_PM25_CONCENTRATION.toString());
	public static final URI CONFIG_DESCRIPTION_URI_PARTICULATE_MATTER_PM100_CONCENTRATION = URI.create("channel-type:"+CHANNEL_TYPE_PARTICULATE_MATTER_PM100_CONCENTRATION.toString());
	public static final URI CONFIG_DESCRIPTION_URI_PARTICULATE_MATTER_PART_COUNT_3 = URI.create("channel-type:"+CHANNEL_TYPE_PARTICULATE_MATTER_PART_COUNT_3.toString());
	public static final URI CONFIG_DESCRIPTION_URI_PARTICULATE_MATTER_PART_COUNT_5 = URI.create("channel-type:"+CHANNEL_TYPE_PARTICULATE_MATTER_PART_COUNT_5.toString());
	public static final URI CONFIG_DESCRIPTION_URI_PARTICULATE_MATTER_PART_COUNT_10 = URI.create("channel-type:"+CHANNEL_TYPE_PARTICULATE_MATTER_PART_COUNT_10.toString());
	public static final URI CONFIG_DESCRIPTION_URI_PARTICULATE_MATTER_PART_COUNT_25 = URI.create("channel-type:"+CHANNEL_TYPE_PARTICULATE_MATTER_PART_COUNT_25.toString());
	public static final URI CONFIG_DESCRIPTION_URI_PARTICULATE_MATTER_PART_COUNT_50 = URI.create("channel-type:"+CHANNEL_TYPE_PARTICULATE_MATTER_PART_COUNT_50.toString());
	public static final URI CONFIG_DESCRIPTION_URI_PARTICULATE_MATTER_PART_COUNT_100 = URI.create("channel-type:"+CHANNEL_TYPE_PARTICULATE_MATTER_PART_COUNT_100.toString());
	public static final URI CONFIG_DESCRIPTION_URI_PARTICULATE_MATTER_SENSOR_ENABLED = URI.create("channel-type:"+CHANNEL_TYPE_PARTICULATE_MATTER_SENSOR_ENABLED.toString());
	public static final URI CONFIG_DESCRIPTION_URI_PARTICULATE_MATTER = URI.create("thing-type:"+THING_TYPE_PARTICULATE_MATTER.toString());
	public static final URI CONFIG_DESCRIPTION_URI_PIEZO_BUZZER = URI.create("thing-type:"+THING_TYPE_PIEZO_BUZZER.toString());
	public static final URI CONFIG_DESCRIPTION_URI_PIEZO_SPEAKER = URI.create("thing-type:"+THING_TYPE_PIEZO_SPEAKER.toString());
	public static final URI CONFIG_DESCRIPTION_URI_PIEZO_SPEAKER_V2 = URI.create("thing-type:"+THING_TYPE_PIEZO_SPEAKER_V2.toString());
	public static final URI CONFIG_DESCRIPTION_URI_PTC_TEMPERATURE = URI.create("channel-type:"+CHANNEL_TYPE_PTC_TEMPERATURE.toString());
	public static final URI CONFIG_DESCRIPTION_URI_PTC_SENSOR_CONNECTED = URI.create("channel-type:"+CHANNEL_TYPE_PTC_SENSOR_CONNECTED.toString());
	public static final URI CONFIG_DESCRIPTION_URI_PTC = URI.create("thing-type:"+THING_TYPE_PTC.toString());
	public static final URI CONFIG_DESCRIPTION_URI_PTC_V2_TEMPERATURE = URI.create("channel-type:"+CHANNEL_TYPE_PTC_V2_TEMPERATURE.toString());
	public static final URI CONFIG_DESCRIPTION_URI_PTC_V2_SENSOR_CONNECTED = URI.create("channel-type:"+CHANNEL_TYPE_PTC_V2_SENSOR_CONNECTED.toString());
	public static final URI CONFIG_DESCRIPTION_URI_PTC_V2 = URI.create("thing-type:"+THING_TYPE_PTC_V2.toString());
	public static final URI CONFIG_DESCRIPTION_URI_REAL_TIME_CLOCK_DATE_TIME = URI.create("channel-type:"+CHANNEL_TYPE_REAL_TIME_CLOCK_DATE_TIME.toString());
	public static final URI CONFIG_DESCRIPTION_URI_REAL_TIME_CLOCK_TIMESTAMP = URI.create("channel-type:"+CHANNEL_TYPE_REAL_TIME_CLOCK_TIMESTAMP.toString());
	public static final URI CONFIG_DESCRIPTION_URI_REAL_TIME_CLOCK = URI.create("thing-type:"+THING_TYPE_REAL_TIME_CLOCK.toString());
	public static final URI CONFIG_DESCRIPTION_URI_REAL_TIME_CLOCK_V2_DATE_TIME = URI.create("channel-type:"+CHANNEL_TYPE_REAL_TIME_CLOCK_V2_DATE_TIME.toString());
	public static final URI CONFIG_DESCRIPTION_URI_REAL_TIME_CLOCK_V2_TIMESTAMP = URI.create("channel-type:"+CHANNEL_TYPE_REAL_TIME_CLOCK_V2_TIMESTAMP.toString());
	public static final URI CONFIG_DESCRIPTION_URI_REAL_TIME_CLOCK_V2 = URI.create("thing-type:"+THING_TYPE_REAL_TIME_CLOCK_V2.toString());
	public static final URI CONFIG_DESCRIPTION_URI_REMOTE_SWITCH = URI.create("thing-type:"+THING_TYPE_REMOTE_SWITCH.toString());
	public static final URI CONFIG_DESCRIPTION_URI_REMOTE_SWITCH_V2 = URI.create("thing-type:"+THING_TYPE_REMOTE_SWITCH_V2.toString());
	public static final URI CONFIG_DESCRIPTION_URI_RGB_LED_BUTTON_COLOR = URI.create("channel-type:"+CHANNEL_TYPE_RGB_LED_BUTTON_COLOR.toString());
	public static final URI CONFIG_DESCRIPTION_URI_RGB_LED_BUTTON = URI.create("thing-type:"+THING_TYPE_RGB_LED_BUTTON.toString());
	public static final URI CONFIG_DESCRIPTION_URI_RGB_LED = URI.create("thing-type:"+THING_TYPE_RGB_LED.toString());
	public static final URI CONFIG_DESCRIPTION_URI_RGB_LED_MATRIX = URI.create("thing-type:"+THING_TYPE_RGB_LED_MATRIX.toString());
	public static final URI CONFIG_DESCRIPTION_URI_RGB_LED_V2 = URI.create("thing-type:"+THING_TYPE_RGB_LED_V2.toString());
	public static final URI CONFIG_DESCRIPTION_URI_ROTARY_ENCODER_COUNT = URI.create("channel-type:"+CHANNEL_TYPE_ROTARY_ENCODER_COUNT.toString());
	public static final URI CONFIG_DESCRIPTION_URI_ROTARY_ENCODER_RESET_COUNTER = URI.create("channel-type:"+CHANNEL_TYPE_ROTARY_ENCODER_RESET_COUNTER.toString());
	public static final URI CONFIG_DESCRIPTION_URI_ROTARY_ENCODER = URI.create("thing-type:"+THING_TYPE_ROTARY_ENCODER.toString());
	public static final URI CONFIG_DESCRIPTION_URI_ROTARY_ENCODER_V2 = URI.create("thing-type:"+THING_TYPE_ROTARY_ENCODER_V2.toString());
	public static final URI CONFIG_DESCRIPTION_URI_ROTARY_POTI = URI.create("thing-type:"+THING_TYPE_ROTARY_POTI.toString());
	public static final URI CONFIG_DESCRIPTION_URI_ROTARY_POTI_V2_POSITION = URI.create("channel-type:"+CHANNEL_TYPE_ROTARY_POTI_V2_POSITION.toString());
	public static final URI CONFIG_DESCRIPTION_URI_ROTARY_POTI_V2 = URI.create("thing-type:"+THING_TYPE_ROTARY_POTI_V2.toString());
	public static final URI CONFIG_DESCRIPTION_URI_RS232 = URI.create("thing-type:"+THING_TYPE_RS232.toString());
	public static final URI CONFIG_DESCRIPTION_URI_RS232_V2 = URI.create("thing-type:"+THING_TYPE_RS232_V2.toString());
	public static final URI CONFIG_DESCRIPTION_URI_RS485 = URI.create("thing-type:"+THING_TYPE_RS485.toString());
	public static final URI CONFIG_DESCRIPTION_URI_SEGMENT_DISPLAY_4X7 = URI.create("thing-type:"+THING_TYPE_SEGMENT_DISPLAY_4X7.toString());
	public static final URI CONFIG_DESCRIPTION_URI_SEGMENT_DISPLAY_4X7_V2 = URI.create("thing-type:"+THING_TYPE_SEGMENT_DISPLAY_4X7_V2.toString());
	public static final URI CONFIG_DESCRIPTION_URI_SOLID_STATE_RELAY_RELAY = URI.create("channel-type:"+CHANNEL_TYPE_SOLID_STATE_RELAY_RELAY.toString());
	public static final URI CONFIG_DESCRIPTION_URI_SOLID_STATE_RELAY_MONOFLOP = URI.create("channel-type:"+CHANNEL_TYPE_SOLID_STATE_RELAY_MONOFLOP.toString());
	public static final URI CONFIG_DESCRIPTION_URI_SOLID_STATE_RELAY = URI.create("thing-type:"+THING_TYPE_SOLID_STATE_RELAY.toString());
	public static final URI CONFIG_DESCRIPTION_URI_SOLID_STATE_RELAY_V2_RELAY = URI.create("channel-type:"+CHANNEL_TYPE_SOLID_STATE_RELAY_V2_RELAY.toString());
	public static final URI CONFIG_DESCRIPTION_URI_SOLID_STATE_RELAY_V2_MONOFLOP = URI.create("channel-type:"+CHANNEL_TYPE_SOLID_STATE_RELAY_V2_MONOFLOP.toString());
	public static final URI CONFIG_DESCRIPTION_URI_SOLID_STATE_RELAY_V2 = URI.create("thing-type:"+THING_TYPE_SOLID_STATE_RELAY_V2.toString());
	public static final URI CONFIG_DESCRIPTION_URI_SOUND_INTENSITY_INTENSITY = URI.create("channel-type:"+CHANNEL_TYPE_SOUND_INTENSITY_INTENSITY.toString());
	public static final URI CONFIG_DESCRIPTION_URI_SOUND_INTENSITY = URI.create("thing-type:"+THING_TYPE_SOUND_INTENSITY.toString());
	public static final URI CONFIG_DESCRIPTION_URI_SOUND_PRESSURE_LEVEL_SOUND_PRESSURE = URI.create("channel-type:"+CHANNEL_TYPE_SOUND_PRESSURE_LEVEL_SOUND_PRESSURE.toString());
	public static final URI CONFIG_DESCRIPTION_URI_SOUND_PRESSURE_LEVEL = URI.create("thing-type:"+THING_TYPE_SOUND_PRESSURE_LEVEL.toString());
	public static final URI CONFIG_DESCRIPTION_URI_TEMPERATURE_TEMPERATURE = URI.create("channel-type:"+CHANNEL_TYPE_TEMPERATURE_TEMPERATURE.toString());
	public static final URI CONFIG_DESCRIPTION_URI_TEMPERATURE = URI.create("thing-type:"+THING_TYPE_TEMPERATURE.toString());
	public static final URI CONFIG_DESCRIPTION_URI_TEMPERATURE_IR_AMBIENT_TEMPERATURE = URI.create("channel-type:"+CHANNEL_TYPE_TEMPERATURE_IR_AMBIENT_TEMPERATURE.toString());
	public static final URI CONFIG_DESCRIPTION_URI_TEMPERATURE_IR_OBJECT_TEMPERATURE = URI.create("channel-type:"+CHANNEL_TYPE_TEMPERATURE_IR_OBJECT_TEMPERATURE.toString());
	public static final URI CONFIG_DESCRIPTION_URI_TEMPERATURE_IR = URI.create("thing-type:"+THING_TYPE_TEMPERATURE_IR.toString());
	public static final URI CONFIG_DESCRIPTION_URI_TEMPERATURE_IR_V2_AMBIENT_TEMPERATURE = URI.create("channel-type:"+CHANNEL_TYPE_TEMPERATURE_IR_V2_AMBIENT_TEMPERATURE.toString());
	public static final URI CONFIG_DESCRIPTION_URI_TEMPERATURE_IR_V2_OBJECT_TEMPERATURE = URI.create("channel-type:"+CHANNEL_TYPE_TEMPERATURE_IR_V2_OBJECT_TEMPERATURE.toString());
	public static final URI CONFIG_DESCRIPTION_URI_TEMPERATURE_IR_V2 = URI.create("thing-type:"+THING_TYPE_TEMPERATURE_IR_V2.toString());
	public static final URI CONFIG_DESCRIPTION_URI_TEMPERATURE_V2_TEMPERATURE = URI.create("channel-type:"+CHANNEL_TYPE_TEMPERATURE_V2_TEMPERATURE.toString());
	public static final URI CONFIG_DESCRIPTION_URI_TEMPERATURE_V2 = URI.create("thing-type:"+THING_TYPE_TEMPERATURE_V2.toString());
	public static final URI CONFIG_DESCRIPTION_URI_THERMAL_IMAGING = URI.create("thing-type:"+THING_TYPE_THERMAL_IMAGING.toString());
	public static final URI CONFIG_DESCRIPTION_URI_THERMOCOUPLE = URI.create("thing-type:"+THING_TYPE_THERMOCOUPLE.toString());
	public static final URI CONFIG_DESCRIPTION_URI_THERMOCOUPLE_V2 = URI.create("thing-type:"+THING_TYPE_THERMOCOUPLE_V2.toString());
	public static final URI CONFIG_DESCRIPTION_URI_TILT = URI.create("thing-type:"+THING_TYPE_TILT.toString());
	public static final URI CONFIG_DESCRIPTION_URI_UV_LIGHT_UV_INDEX = URI.create("channel-type:"+CHANNEL_TYPE_UV_LIGHT_UV_INDEX.toString());
	public static final URI CONFIG_DESCRIPTION_URI_UV_LIGHT = URI.create("thing-type:"+THING_TYPE_UV_LIGHT.toString());
	public static final URI CONFIG_DESCRIPTION_URI_UV_LIGHT_V2_UVA_INTENSITY = URI.create("channel-type:"+CHANNEL_TYPE_UV_LIGHT_V2_UVA_INTENSITY.toString());
	public static final URI CONFIG_DESCRIPTION_URI_UV_LIGHT_V2_UVB_INTENSITY = URI.create("channel-type:"+CHANNEL_TYPE_UV_LIGHT_V2_UVB_INTENSITY.toString());
	public static final URI CONFIG_DESCRIPTION_URI_UV_LIGHT_V2_UV_INDEX = URI.create("channel-type:"+CHANNEL_TYPE_UV_LIGHT_V2_UV_INDEX.toString());
	public static final URI CONFIG_DESCRIPTION_URI_UV_LIGHT_V2 = URI.create("thing-type:"+THING_TYPE_UV_LIGHT_V2.toString());
	public static final URI CONFIG_DESCRIPTION_URI_VOLTAGE = URI.create("thing-type:"+THING_TYPE_VOLTAGE.toString());
	public static final URI CONFIG_DESCRIPTION_URI_VOLTAGE_CURRENT = URI.create("thing-type:"+THING_TYPE_VOLTAGE_CURRENT.toString());
	public static final URI CONFIG_DESCRIPTION_URI_VOLTAGE_CURRENT_V2_VOLTAGE = URI.create("channel-type:"+CHANNEL_TYPE_VOLTAGE_CURRENT_V2_VOLTAGE.toString());
	public static final URI CONFIG_DESCRIPTION_URI_VOLTAGE_CURRENT_V2_CURRENT = URI.create("channel-type:"+CHANNEL_TYPE_VOLTAGE_CURRENT_V2_CURRENT.toString());
	public static final URI CONFIG_DESCRIPTION_URI_VOLTAGE_CURRENT_V2_POWER = URI.create("channel-type:"+CHANNEL_TYPE_VOLTAGE_CURRENT_V2_POWER.toString());
	public static final URI CONFIG_DESCRIPTION_URI_VOLTAGE_CURRENT_V2 = URI.create("thing-type:"+THING_TYPE_VOLTAGE_CURRENT_V2.toString());
	public static final URI CONFIG_DESCRIPTION_URI_XMC1400_BREAKOUT = URI.create("thing-type:"+THING_TYPE_XMC1400_BREAKOUT.toString());

    public static final Map<URI, ThingTypeUID> SUPPORTED_CONFIG_DESCRIPTIONS;

    static {
        SUPPORTED_CONFIG_DESCRIPTIONS = new HashMap<>();
        SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_BRICK_DAEMON, THING_TYPE_BRICK_DAEMON);
        SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_DC, THING_TYPE_DC);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_HAT, THING_TYPE_HAT);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_HAT_ZERO, THING_TYPE_HAT_ZERO);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_IMU, THING_TYPE_IMU);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_IMU_V2, THING_TYPE_IMU_V2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_MASTER, THING_TYPE_MASTER);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_RED, THING_TYPE_RED);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_SERVO, THING_TYPE_SERVO);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_SILENT_STEPPER, THING_TYPE_SILENT_STEPPER);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_STEPPER, THING_TYPE_STEPPER);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_ACCELEROMETER, THING_TYPE_ACCELEROMETER);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_ACCELEROMETER_V2, THING_TYPE_ACCELEROMETER_V2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_AIR_QUALITY_HUMIDITY, THING_TYPE_AIR_QUALITY);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_AIR_QUALITY_TEMPERATURE, THING_TYPE_AIR_QUALITY);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_AIR_QUALITY_AIR_PRESSURE, THING_TYPE_AIR_QUALITY);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_AIR_QUALITY_IAQ_INDEX, THING_TYPE_AIR_QUALITY);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_AIR_QUALITY_IAQ_INDEX_ACCURACY, THING_TYPE_AIR_QUALITY);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_AIR_QUALITY, THING_TYPE_AIR_QUALITY);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_AMBIENT_LIGHT_ILLUMINANCE, THING_TYPE_AMBIENT_LIGHT);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_AMBIENT_LIGHT, THING_TYPE_AMBIENT_LIGHT);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_AMBIENT_LIGHT_V2_ILLUMINANCE, THING_TYPE_AMBIENT_LIGHT_V2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_AMBIENT_LIGHT_V2, THING_TYPE_AMBIENT_LIGHT_V2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_AMBIENT_LIGHT_V3_ILLUMINANCE, THING_TYPE_AMBIENT_LIGHT_V3);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_AMBIENT_LIGHT_V3, THING_TYPE_AMBIENT_LIGHT_V3);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_ANALOG_IN, THING_TYPE_ANALOG_IN);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_ANALOG_IN_V2, THING_TYPE_ANALOG_IN_V2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_ANALOG_IN_V3_VOLTAGE, THING_TYPE_ANALOG_IN_V3);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_ANALOG_IN_V3, THING_TYPE_ANALOG_IN_V3);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_ANALOG_OUT, THING_TYPE_ANALOG_OUT);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_ANALOG_OUT_V2, THING_TYPE_ANALOG_OUT_V2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_ANALOG_OUT_V3, THING_TYPE_ANALOG_OUT_V3);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_BAROMETER_AIR_PRESSURE, THING_TYPE_BAROMETER);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_BAROMETER_ALTITUDE, THING_TYPE_BAROMETER);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_BAROMETER, THING_TYPE_BAROMETER);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_BAROMETER_V2_AIR_PRESSURE, THING_TYPE_BAROMETER_V2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_BAROMETER_V2_ALTITUDE, THING_TYPE_BAROMETER_V2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_BAROMETER_V2_TEMPERATURE, THING_TYPE_BAROMETER_V2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_BAROMETER_V2, THING_TYPE_BAROMETER_V2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_CAN, THING_TYPE_CAN);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_CAN_V2, THING_TYPE_CAN_V2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_CO2, THING_TYPE_CO2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_CO2_V2, THING_TYPE_CO2_V2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_COLOR_COLOR, THING_TYPE_COLOR);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_COLOR, THING_TYPE_COLOR);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_COLOR_V2_COLOR, THING_TYPE_COLOR_V2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_COLOR_V2_ILLUMINANCE, THING_TYPE_COLOR_V2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_COLOR_V2_COLOR_TEMPERATURE, THING_TYPE_COLOR_V2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_COLOR_V2_LIGHT, THING_TYPE_COLOR_V2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_COLOR_V2, THING_TYPE_COLOR_V2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_COMPASS_HEADING, THING_TYPE_COMPASS);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_COMPASS, THING_TYPE_COMPASS);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_CURRENT12, THING_TYPE_CURRENT12);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_CURRENT25, THING_TYPE_CURRENT25);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_DISTANCE_IR_DISTANCE, THING_TYPE_DISTANCE_IR);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_DISTANCE_IR, THING_TYPE_DISTANCE_IR);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_DISTANCE_IR_V2_DISTANCE, THING_TYPE_DISTANCE_IR_V2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_DISTANCE_IR_V2, THING_TYPE_DISTANCE_IR_V2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_DISTANCE_US_DISTANCE, THING_TYPE_DISTANCE_US);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_DISTANCE_US, THING_TYPE_DISTANCE_US);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_DISTANCE_US_V2_DISTANCE, THING_TYPE_DISTANCE_US_V2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_DISTANCE_US_V2, THING_TYPE_DISTANCE_US_V2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_DMX, THING_TYPE_DMX);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_DUAL_BUTTON, THING_TYPE_DUAL_BUTTON);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_DUAL_BUTTON_V2, THING_TYPE_DUAL_BUTTON_V2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_DUAL_RELAY_RELAY, THING_TYPE_DUAL_RELAY);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_DUAL_RELAY_MONOFLOP, THING_TYPE_DUAL_RELAY);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_DUAL_RELAY, THING_TYPE_DUAL_RELAY);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_DUST_DETECTOR, THING_TYPE_DUST_DETECTOR);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_E_PAPER_296X128, THING_TYPE_E_PAPER_296X128);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_ENERGY_MONITOR_VOLTAGE, THING_TYPE_ENERGY_MONITOR);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_ENERGY_MONITOR_CURRENT, THING_TYPE_ENERGY_MONITOR);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_ENERGY_MONITOR_ENERGY, THING_TYPE_ENERGY_MONITOR);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_ENERGY_MONITOR_REALPOWER, THING_TYPE_ENERGY_MONITOR);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_ENERGY_MONITOR_APPPOWER, THING_TYPE_ENERGY_MONITOR);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_ENERGY_MONITOR_REACPOWER, THING_TYPE_ENERGY_MONITOR);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_ENERGY_MONITOR_FACTOR, THING_TYPE_ENERGY_MONITOR);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_ENERGY_MONITOR_FREQUENCY, THING_TYPE_ENERGY_MONITOR);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_ENERGY_MONITOR_RESET, THING_TYPE_ENERGY_MONITOR);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_ENERGY_MONITOR, THING_TYPE_ENERGY_MONITOR);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_GPS, THING_TYPE_GPS);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_GPS_V2, THING_TYPE_GPS_V2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_HALL_EFFECT, THING_TYPE_HALL_EFFECT);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_HALL_EFFECT_V2, THING_TYPE_HALL_EFFECT_V2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_HUMIDITY_HUMIDITY, THING_TYPE_HUMIDITY);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_HUMIDITY, THING_TYPE_HUMIDITY);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_HUMIDITY_V2_HUMIDITY, THING_TYPE_HUMIDITY_V2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_HUMIDITY_V2_TEMPERATURE, THING_TYPE_HUMIDITY_V2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_HUMIDITY_V2, THING_TYPE_HUMIDITY_V2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_INDUSTRIAL_ANALOG_OUT, THING_TYPE_INDUSTRIAL_ANALOG_OUT);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_INDUSTRIAL_ANALOG_OUT_V2_ENABLED, THING_TYPE_INDUSTRIAL_ANALOG_OUT_V2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_INDUSTRIAL_ANALOG_OUT_V2_VOLTAGE, THING_TYPE_INDUSTRIAL_ANALOG_OUT_V2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_INDUSTRIAL_ANALOG_OUT_V2_CURRENT, THING_TYPE_INDUSTRIAL_ANALOG_OUT_V2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_INDUSTRIAL_ANALOG_OUT_V2, THING_TYPE_INDUSTRIAL_ANALOG_OUT_V2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_INDUSTRIAL_COUNTER, THING_TYPE_INDUSTRIAL_COUNTER);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_INDUSTRIAL_DIGITAL_IN_4, THING_TYPE_INDUSTRIAL_DIGITAL_IN_4);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_INDUSTRIAL_DIGITAL_IN_4_V2_INPUT, THING_TYPE_INDUSTRIAL_DIGITAL_IN_4_V2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_INDUSTRIAL_DIGITAL_IN_4_V2_EDGE_COUNT, THING_TYPE_INDUSTRIAL_DIGITAL_IN_4_V2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_INDUSTRIAL_DIGITAL_IN_4_V2, THING_TYPE_INDUSTRIAL_DIGITAL_IN_4_V2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_INDUSTRIAL_DIGITAL_OUT_4, THING_TYPE_INDUSTRIAL_DIGITAL_OUT_4);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_INDUSTRIAL_DIGITAL_OUT_4_V2, THING_TYPE_INDUSTRIAL_DIGITAL_OUT_4_V2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_INDUSTRIAL_DUAL_0_20MA, THING_TYPE_INDUSTRIAL_DUAL_0_20MA);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_INDUSTRIAL_DUAL_0_20MA_V2, THING_TYPE_INDUSTRIAL_DUAL_0_20MA_V2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_INDUSTRIAL_DUAL_ANALOG_IN_VOLTAGE, THING_TYPE_INDUSTRIAL_DUAL_ANALOG_IN);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_INDUSTRIAL_DUAL_ANALOG_IN, THING_TYPE_INDUSTRIAL_DUAL_ANALOG_IN);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_INDUSTRIAL_DUAL_ANALOG_IN_V2_VOLTAGE, THING_TYPE_INDUSTRIAL_DUAL_ANALOG_IN_V2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_INDUSTRIAL_DUAL_ANALOG_IN_V2, THING_TYPE_INDUSTRIAL_DUAL_ANALOG_IN_V2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_INDUSTRIAL_DUAL_RELAY_RELAY, THING_TYPE_INDUSTRIAL_DUAL_RELAY);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_INDUSTRIAL_DUAL_RELAY_MONOFLOP, THING_TYPE_INDUSTRIAL_DUAL_RELAY);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_INDUSTRIAL_DUAL_RELAY, THING_TYPE_INDUSTRIAL_DUAL_RELAY);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_INDUSTRIAL_QUAD_RELAY_RELAY, THING_TYPE_INDUSTRIAL_QUAD_RELAY);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_INDUSTRIAL_QUAD_RELAY_MONOFLOP, THING_TYPE_INDUSTRIAL_QUAD_RELAY);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_INDUSTRIAL_QUAD_RELAY, THING_TYPE_INDUSTRIAL_QUAD_RELAY);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_INDUSTRIAL_QUAD_RELAY_V2_RELAY, THING_TYPE_INDUSTRIAL_QUAD_RELAY_V2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_INDUSTRIAL_QUAD_RELAY_V2_MONOFLOP, THING_TYPE_INDUSTRIAL_QUAD_RELAY_V2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_INDUSTRIAL_QUAD_RELAY_V2, THING_TYPE_INDUSTRIAL_QUAD_RELAY_V2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_IO16_INPUT_PIN, THING_TYPE_IO16);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_IO16_OUTPUT_PIN, THING_TYPE_IO16);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_IO16_MONOFLOP, THING_TYPE_IO16);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_IO16_EDGE_COUNT, THING_TYPE_IO16);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_IO16, THING_TYPE_IO16);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_IO16_V2_INPUT_PIN, THING_TYPE_IO16_V2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_IO16_V2_OUTPUT_PIN, THING_TYPE_IO16_V2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_IO16_V2_MONOFLOP, THING_TYPE_IO16_V2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_IO16_V2_EDGE_COUNT, THING_TYPE_IO16_V2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_IO16_V2, THING_TYPE_IO16_V2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_IO4_INPUT_PIN, THING_TYPE_IO4);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_IO4_OUTPUT_PIN, THING_TYPE_IO4);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_IO4_MONOFLOP, THING_TYPE_IO4);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_IO4_EDGE_COUNT, THING_TYPE_IO4);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_IO4, THING_TYPE_IO4);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_IO4_V2_INPUT_PIN, THING_TYPE_IO4_V2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_IO4_V2_OUTPUT_PIN, THING_TYPE_IO4_V2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_IO4_V2_MONOFLOP, THING_TYPE_IO4_V2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_IO4_V2_EDGE_COUNT, THING_TYPE_IO4_V2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_IO4_V2, THING_TYPE_IO4_V2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_ISOLATOR, THING_TYPE_ISOLATOR);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_JOYSTICK, THING_TYPE_JOYSTICK);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_JOYSTICK_V2, THING_TYPE_JOYSTICK_V2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_LASER_RANGE_FINDER, THING_TYPE_LASER_RANGE_FINDER);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_LASER_RANGE_FINDER_V2, THING_TYPE_LASER_RANGE_FINDER_V2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_LCD_128X64_TEXT, THING_TYPE_LCD_128X64);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_LCD_128X64_CLEAR_DISPLAY, THING_TYPE_LCD_128X64);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_LCD_128X64_DRAW_BUFFERED_FRAME, THING_TYPE_LCD_128X64);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_LCD_128X64, THING_TYPE_LCD_128X64);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_LCD_16X2_TEXT, THING_TYPE_LCD_16X2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_LCD_16X2_CLEAR_DISPLAY, THING_TYPE_LCD_16X2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_LCD_16X2_BACKLIGHT, THING_TYPE_LCD_16X2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_LCD_16X2, THING_TYPE_LCD_16X2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_LCD_20X4_TEXT, THING_TYPE_LCD_20X4);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_LCD_20X4_CLEAR_DISPLAY, THING_TYPE_LCD_20X4);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_LCD_20X4_BACKLIGHT, THING_TYPE_LCD_20X4);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_LCD_20X4, THING_TYPE_LCD_20X4);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_LED_STRIP, THING_TYPE_LED_STRIP);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_LED_STRIP_V2, THING_TYPE_LED_STRIP_V2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_LINE, THING_TYPE_LINE);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_LINEAR_POTI, THING_TYPE_LINEAR_POTI);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_LINEAR_POTI_V2, THING_TYPE_LINEAR_POTI_V2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_LOAD_CELL_WEIGHT, THING_TYPE_LOAD_CELL);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_LOAD_CELL_TARE, THING_TYPE_LOAD_CELL);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_LOAD_CELL, THING_TYPE_LOAD_CELL);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_LOAD_CELL_V2_WEIGHT, THING_TYPE_LOAD_CELL_V2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_LOAD_CELL_V2_TARE, THING_TYPE_LOAD_CELL_V2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_LOAD_CELL_V2, THING_TYPE_LOAD_CELL_V2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_MOISTURE, THING_TYPE_MOISTURE);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_MOTION_DETECTOR, THING_TYPE_MOTION_DETECTOR);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_MOTION_DETECTOR_V2_INDICATOR, THING_TYPE_MOTION_DETECTOR_V2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_MOTION_DETECTOR_V2, THING_TYPE_MOTION_DETECTOR_V2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_MOTORIZED_LINEAR_POTI, THING_TYPE_MOTORIZED_LINEAR_POTI);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_MULTI_TOUCH_ELECTRODE, THING_TYPE_MULTI_TOUCH);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_MULTI_TOUCH_RECALIBRATE, THING_TYPE_MULTI_TOUCH);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_MULTI_TOUCH, THING_TYPE_MULTI_TOUCH);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_MULTI_TOUCH_V2_ELECTRODE, THING_TYPE_MULTI_TOUCH_V2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_MULTI_TOUCH_V2_RECALIBRATE, THING_TYPE_MULTI_TOUCH_V2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_MULTI_TOUCH_V2, THING_TYPE_MULTI_TOUCH_V2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_NFC, THING_TYPE_NFC);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_NFC_RFID, THING_TYPE_NFC_RFID);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_OLED_128X64_TEXT, THING_TYPE_OLED_128X64);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_OLED_128X64_CLEAR_DISPLAY, THING_TYPE_OLED_128X64);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_OLED_128X64, THING_TYPE_OLED_128X64);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_OLED_128X64_V2_TEXT, THING_TYPE_OLED_128X64_V2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_OLED_128X64_V2_CLEAR_DISPLAY, THING_TYPE_OLED_128X64_V2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_OLED_128X64_V2_DRAW_BUFFERED_FRAME, THING_TYPE_OLED_128X64_V2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_OLED_128X64_V2, THING_TYPE_OLED_128X64_V2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_OLED_64X48_TEXT, THING_TYPE_OLED_64X48);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_OLED_64X48_CLEAR_DISPLAY, THING_TYPE_OLED_64X48);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_OLED_64X48, THING_TYPE_OLED_64X48);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_ONE_WIRE, THING_TYPE_ONE_WIRE);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_OUTDOOR_WEATHER, THING_TYPE_OUTDOOR_WEATHER);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_PARTICULATE_MATTER_PM10_CONCENTRATION, THING_TYPE_PARTICULATE_MATTER);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_PARTICULATE_MATTER_PM25_CONCENTRATION, THING_TYPE_PARTICULATE_MATTER);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_PARTICULATE_MATTER_PM100_CONCENTRATION, THING_TYPE_PARTICULATE_MATTER);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_PARTICULATE_MATTER_PART_COUNT_3, THING_TYPE_PARTICULATE_MATTER);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_PARTICULATE_MATTER_PART_COUNT_5, THING_TYPE_PARTICULATE_MATTER);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_PARTICULATE_MATTER_PART_COUNT_10, THING_TYPE_PARTICULATE_MATTER);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_PARTICULATE_MATTER_PART_COUNT_25, THING_TYPE_PARTICULATE_MATTER);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_PARTICULATE_MATTER_PART_COUNT_50, THING_TYPE_PARTICULATE_MATTER);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_PARTICULATE_MATTER_PART_COUNT_100, THING_TYPE_PARTICULATE_MATTER);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_PARTICULATE_MATTER_SENSOR_ENABLED, THING_TYPE_PARTICULATE_MATTER);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_PARTICULATE_MATTER, THING_TYPE_PARTICULATE_MATTER);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_PIEZO_BUZZER, THING_TYPE_PIEZO_BUZZER);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_PIEZO_SPEAKER, THING_TYPE_PIEZO_SPEAKER);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_PIEZO_SPEAKER_V2, THING_TYPE_PIEZO_SPEAKER_V2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_PTC_TEMPERATURE, THING_TYPE_PTC);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_PTC_SENSOR_CONNECTED, THING_TYPE_PTC);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_PTC, THING_TYPE_PTC);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_PTC_V2_TEMPERATURE, THING_TYPE_PTC_V2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_PTC_V2_SENSOR_CONNECTED, THING_TYPE_PTC_V2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_PTC_V2, THING_TYPE_PTC_V2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_REAL_TIME_CLOCK_DATE_TIME, THING_TYPE_REAL_TIME_CLOCK);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_REAL_TIME_CLOCK_TIMESTAMP, THING_TYPE_REAL_TIME_CLOCK);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_REAL_TIME_CLOCK, THING_TYPE_REAL_TIME_CLOCK);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_REAL_TIME_CLOCK_V2_DATE_TIME, THING_TYPE_REAL_TIME_CLOCK_V2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_REAL_TIME_CLOCK_V2_TIMESTAMP, THING_TYPE_REAL_TIME_CLOCK_V2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_REAL_TIME_CLOCK_V2, THING_TYPE_REAL_TIME_CLOCK_V2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_REMOTE_SWITCH, THING_TYPE_REMOTE_SWITCH);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_REMOTE_SWITCH_V2, THING_TYPE_REMOTE_SWITCH_V2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_RGB_LED_BUTTON_COLOR, THING_TYPE_RGB_LED_BUTTON);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_RGB_LED_BUTTON, THING_TYPE_RGB_LED_BUTTON);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_RGB_LED, THING_TYPE_RGB_LED);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_RGB_LED_MATRIX, THING_TYPE_RGB_LED_MATRIX);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_RGB_LED_V2, THING_TYPE_RGB_LED_V2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_ROTARY_ENCODER_COUNT, THING_TYPE_ROTARY_ENCODER);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_ROTARY_ENCODER_RESET_COUNTER, THING_TYPE_ROTARY_ENCODER);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_ROTARY_ENCODER, THING_TYPE_ROTARY_ENCODER);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_ROTARY_ENCODER_V2, THING_TYPE_ROTARY_ENCODER_V2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_ROTARY_POTI, THING_TYPE_ROTARY_POTI);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_ROTARY_POTI_V2_POSITION, THING_TYPE_ROTARY_POTI_V2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_ROTARY_POTI_V2, THING_TYPE_ROTARY_POTI_V2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_RS232, THING_TYPE_RS232);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_RS232_V2, THING_TYPE_RS232_V2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_RS485, THING_TYPE_RS485);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_SEGMENT_DISPLAY_4X7, THING_TYPE_SEGMENT_DISPLAY_4X7);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_SEGMENT_DISPLAY_4X7_V2, THING_TYPE_SEGMENT_DISPLAY_4X7_V2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_SOLID_STATE_RELAY_RELAY, THING_TYPE_SOLID_STATE_RELAY);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_SOLID_STATE_RELAY_MONOFLOP, THING_TYPE_SOLID_STATE_RELAY);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_SOLID_STATE_RELAY, THING_TYPE_SOLID_STATE_RELAY);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_SOLID_STATE_RELAY_V2_RELAY, THING_TYPE_SOLID_STATE_RELAY_V2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_SOLID_STATE_RELAY_V2_MONOFLOP, THING_TYPE_SOLID_STATE_RELAY_V2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_SOLID_STATE_RELAY_V2, THING_TYPE_SOLID_STATE_RELAY_V2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_SOUND_INTENSITY_INTENSITY, THING_TYPE_SOUND_INTENSITY);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_SOUND_INTENSITY, THING_TYPE_SOUND_INTENSITY);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_SOUND_PRESSURE_LEVEL_SOUND_PRESSURE, THING_TYPE_SOUND_PRESSURE_LEVEL);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_SOUND_PRESSURE_LEVEL, THING_TYPE_SOUND_PRESSURE_LEVEL);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_TEMPERATURE_TEMPERATURE, THING_TYPE_TEMPERATURE);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_TEMPERATURE, THING_TYPE_TEMPERATURE);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_TEMPERATURE_IR_AMBIENT_TEMPERATURE, THING_TYPE_TEMPERATURE_IR);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_TEMPERATURE_IR_OBJECT_TEMPERATURE, THING_TYPE_TEMPERATURE_IR);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_TEMPERATURE_IR, THING_TYPE_TEMPERATURE_IR);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_TEMPERATURE_IR_V2_AMBIENT_TEMPERATURE, THING_TYPE_TEMPERATURE_IR_V2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_TEMPERATURE_IR_V2_OBJECT_TEMPERATURE, THING_TYPE_TEMPERATURE_IR_V2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_TEMPERATURE_IR_V2, THING_TYPE_TEMPERATURE_IR_V2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_TEMPERATURE_V2_TEMPERATURE, THING_TYPE_TEMPERATURE_V2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_TEMPERATURE_V2, THING_TYPE_TEMPERATURE_V2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_THERMAL_IMAGING, THING_TYPE_THERMAL_IMAGING);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_THERMOCOUPLE, THING_TYPE_THERMOCOUPLE);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_THERMOCOUPLE_V2, THING_TYPE_THERMOCOUPLE_V2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_TILT, THING_TYPE_TILT);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_UV_LIGHT_UV_INDEX, THING_TYPE_UV_LIGHT);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_UV_LIGHT, THING_TYPE_UV_LIGHT);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_UV_LIGHT_V2_UVA_INTENSITY, THING_TYPE_UV_LIGHT_V2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_UV_LIGHT_V2_UVB_INTENSITY, THING_TYPE_UV_LIGHT_V2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_UV_LIGHT_V2_UV_INDEX, THING_TYPE_UV_LIGHT_V2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_UV_LIGHT_V2, THING_TYPE_UV_LIGHT_V2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_VOLTAGE, THING_TYPE_VOLTAGE);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_VOLTAGE_CURRENT, THING_TYPE_VOLTAGE_CURRENT);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_VOLTAGE_CURRENT_V2_VOLTAGE, THING_TYPE_VOLTAGE_CURRENT_V2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_VOLTAGE_CURRENT_V2_CURRENT, THING_TYPE_VOLTAGE_CURRENT_V2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_VOLTAGE_CURRENT_V2_POWER, THING_TYPE_VOLTAGE_CURRENT_V2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_VOLTAGE_CURRENT_V2, THING_TYPE_VOLTAGE_CURRENT_V2);
		SUPPORTED_CONFIG_DESCRIPTIONS.put(CONFIG_DESCRIPTION_URI_XMC1400_BREAKOUT, THING_TYPE_XMC1400_BREAKOUT);
    }
}
